<?php
/*
 * Copyright (C) 2009-2013 Laurent Destailleur  <eldy@users.sourceforge.net>
*
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 * or see http://www.gnu.org/
 */

/**
 *      \file       htdocs/custom/containermanagement/lib/commandepdf.lib.php
 *      \ingroup    order
 *      \brief      Function to rebuild PDF and merge PDF files into one
 */

require_once(DOL_DOCUMENT_ROOT.'/core/lib/files.lib.php');
require_once(DOL_DOCUMENT_ROOT.'/core/lib/pdf.lib.php');


/**
 * Function to build a compiled PDF
 *
 * @param	DoliDB		$db					Database handler
 * @param	array		$orders					Array of orders
 * @param	Translate	$langs					Object langs
 * @param	Conf		$conf					Object conf
 * @param	string		$diroutputpdf                           Dir to output file
 * @param	int		$usestdout				Add information onto standard output
 * @param	int		$regenerate				''=Use existing PDF files, 'nameofpdf'=Regenerate all PDF files using the template
 * @param	string		$filesuffix				Suffix to add into file name of generated PDF
 * @param	string		$fileprefix				Prefix to add into filename of generated PDF
 * @return	int							Error code
 */
function rebuild_merge_commandes_pdf($db, $orders, $langs, $conf, $diroutputpdf,  $usestdout, $regenerate=0, $filesuffix='merge', $fileprefix='pickinglist')
{

	//print $sql; exit;
	dol_syslog("rebuild_merge_commandes_pdf", LOG_DEBUG);

	if ($usestdout) print '--- start'."\n";


	$error = 0;
	$result = 0;
	$files = array() ;		// liste les fichiers

	dol_syslog("rebuild_merge_commandes_pdf", LOG_DEBUG);

	    $cpt = 0;
	    $oldemail = '';
	    $message = '';
	    $total = '';

        if (!empty($orders)) {
            
            $uniqueorders = array_unique($orders);
            //print_r($uniqueorders);
            foreach ($uniqueorders as $rowid){
                    
                    dol_syslog("building_commandes_pdf_rowid : " . $rowid, LOG_DEBUG);
                    $com = new Commande($db);
                    $result=$com->fetch($rowid);
                    dol_syslog("building_commandes_pdf_fetch_result : " . $result, LOG_DEBUG);
                    if ($result > 0)
                    {
                            $outputlangs = $langs;
//                            if (! empty($newlangid))
//                            {
//                                    if ($outputlangs->defaultlang != $newlangid)
//                                    {
//                                            $outputlangs = new Translate("",$conf);
//                                            $outputlangs->setDefaultLang($newlangid);
//                                    }
//                            }
                            $originfilename = $conf->commande->dir_output.'/'.$com->ref.'/'.$com->ref.'.pdf';
                            $pickinglistfilename=$conf->commande->dir_output.'/'.$com->ref.'/'.$com->ref.'-pickinglist.pdf';
                            dol_syslog("building_commandes_pdf_filename : " . $filename, LOG_DEBUG);
                            if ($regenerate || ! dol_is_file($filename))
                            {
                                if ($usestdout) print "Build PDF for order ".$com->ref." - Lang = ".$outputlangs->defaultlang."\n";
                                $result= $com->generateDocument('einsteinpicklist', $outputlangs);
                                copy($originfilename,$pickinglistfilename);
                                $result= $com->generateDocument('einstein', $outputlangs);
                            }
                            else {
                                if ($usestdout) print "PDF for order ".$com->ref." already exists\n";
                            }

                            // Add file into files array
                            $files[] = $pickinglistfilename;
                    }

                    if ($result <= 0)
                    {
                            $error++;
                            if ($usestdout) print "Error: Failed to build PDF for order ".($com->ref?$com->ref:' id '.$com->rowid)."\n";
                            else dol_syslog("Failed to build PDF for order ".($com->ref?$com->ref:' id '.$com->rowid), LOG_ERR);
                    }

	            $cpt++;
	        }


	        // Define format of output PDF
	        $formatarray=pdf_getFormat($langs);
	        $page_largeur = $formatarray['width'];
	        $page_hauteur = $formatarray['height'];
	        $format = array($page_largeur,$page_hauteur);

	        if ($usestdout) print "Using output PDF format ".join('x',$format)."\n";
	        else dol_syslog("Using output PDF format ".join('x',$format), LOG_ERR);


	        // Now, build a merged files with all files in $files array
			//---------------------------------------------------------

	        // Create empty PDF
	        $pdf=pdf_getInstance($format);
	        if (class_exists('TCPDF'))
	        {
	            $pdf->setPrintHeader(false);
	            $pdf->setPrintFooter(false);
	        }
	        $pdf->SetFont(pdf_getPDFFont($langs));

	        if ($conf->global->MAIN_DISABLE_PDF_COMPRESSION) $pdf->SetCompression(false);
			//$pdf->SetCompression(false);

			// Add all others
			foreach($files as $file)
			{
	            if ($usestdout) print "Merge PDF file for order ".$file."\n";
	            else dol_syslog("Merge PDF file for order ".$file);

				// Charge un document PDF depuis un fichier.
				$pagecount = $pdf->setSourceFile($file);
				for ($i = 1; $i <= $pagecount; $i++)
	            {
	                 $tplidx = $pdf->importPage($i);
	                 $s = $pdf->getTemplatesize($tplidx);
	                 $pdf->AddPage($s['h'] > $s['w'] ? 'P' : 'L');
	                 $pdf->useTemplate($tplidx);
	            }
			}

			// Create output dir if not exists
			dol_mkdir($diroutputpdf);

			// Save merged file
			$filename=$fileprefix;
			if (empty($filename)) $filename='pickinglist';
			if (! empty($filesuffix)) $filename.='_'.$filesuffix. '_'. date("YmdHis");
			$file=$diroutputpdf.'/'.$filename.'.pdf';

			if (! $error && $pagecount)
			{
				$pdf->Output($file,'F');
				if (! empty($conf->global->MAIN_UMASK))
					@chmod($file, octdec($conf->global->MAIN_UMASK));
			}

			if ($usestdout)
			{
				if (! $error) print "Merged PDF has been built in ".$file."\n";
				else print "Can't build PDF ".$file."\n";
			}

			$result = 1;
	    }
	    else
	    {
	        if ($usestdout) print "No order found for criteria.\n";
	        else dol_syslog("No orders found for criteria");
	        $result = 0;
	    }
	

	if ($error) return -1;
	else return $result;
}

