<?php
/* Copyright (C) 2001-2005 Rodolphe Quiedeville   <rodolphe@quiedeville.org>
 * Copyright (C) 2004-2016 Laurent Destailleur    <eldy@users.sourceforge.net>
 * Copyright (C) 2005      Marc Barilley / Ocebo  <marc@ocebo.com>
 * Copyright (C) 2005-2012 Regis Houssin          <regis.houssin@capnetworks.com>
 * Copyright (C) 2012      Juanjo Menent          <jmenent@2byte.es>
 * Copyright (C) 2013      Christophe Battarel    <christophe.battarel@altairis.fr>
 * Copyright (C) 2013      Cédric Salvador        <csalvador@gpcsolutions.fr>
 * Copyright (C) 2015      Frederic France        <frederic.france@free.fr>
 * Copyright (C) 2015      Marcos García          <marcosgdf@gmail.com>
 * Copyright (C) 2015      Jean-François Ferry    <jfefe@aternatik.fr>
 * Copyright (C) 2016	   Ferran Marcet		  <fmarcet@2byte.es>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

/**
 *	\file       htdocs/custom/containermanagement/list_commande_tri_regroupement.php
 *	\ingroup    commande
 *	\brief      Page to list orders
 */

$res = 0;
// Try main.inc.php using relative path
if (! $res && file_exists("../main.inc.php")) $res=@include("../main.inc.php");
if (! $res && file_exists("../../main.inc.php")) $res=@include("../../main.inc.php");
if (! $res && file_exists("../../../main.inc.php")) $res=@include("../../../main.inc.php");
if (! $res) die("Include of main fails");

require_once DOL_DOCUMENT_ROOT.'/core/lib/date.lib.php';
require_once DOL_DOCUMENT_ROOT.'/core/lib/company.lib.php';
require_once DOL_DOCUMENT_ROOT.'/core/class/discount.class.php';
require_once DOL_DOCUMENT_ROOT.'/core/class/html.formfile.class.php';
require_once DOL_DOCUMENT_ROOT.'/core/class/html.formother.class.php';
require_once DOL_DOCUMENT_ROOT.'/core/class/html.formcompany.class.php';
require_once DOL_DOCUMENT_ROOT.'/commande/class/commande.class.php';
require_once DOL_DOCUMENT_ROOT.'/fourn/class/fournisseur.commande.class.php';
require_once DOL_DOCUMENT_ROOT.'/compta/facture/class/facture.class.php';
require_once DOL_DOCUMENT_ROOT.'/product/class/product.class.php';
require_once DOL_DOCUMENT_ROOT.'/projet/class/project.class.php';

dol_include_once('/containermanagement/class/container.class.php');

// Load translation files required by the page
//$langs->loadLangs(array("orders",'sendings','deliveries','companies','compta','bills'));
// Libre Expert 16/01/2019
$langs->loadLangs(array("orders",'sendings','deliveries','companies','compta','bills',"containermanagement@containermanagement"));

$action=GETPOST('action','aZ09');
$massaction=GETPOST('massaction','alpha');
$show_files=GETPOST('show_files','int');
$confirm=GETPOST('confirm','alpha');
$toselect = GETPOST('toselect', 'array');
$contextpage=GETPOST('contextpage','aZ')?GETPOST('contextpage','aZ'):'orderlist';

$search_orderyear=GETPOST("search_orderyear","int");
$search_ordermonth=GETPOST("search_ordermonth","int");
$search_orderday=GETPOST("search_orderday","int");
$search_deliveryyear=GETPOST("search_deliveryyear","int");
$search_deliverymonth=GETPOST("search_deliverymonth","int");
$search_deliveryday=GETPOST("search_deliveryday","int");
$search_product_category=GETPOST('search_product_category','int');
$search_ref=GETPOST('search_ref','alpha')!=''?GETPOST('search_ref','alpha'):GETPOST('sref','alpha');
$search_ref_customer=GETPOST('search_ref_customer','alpha');
$search_company=GETPOST('search_company','alpha');
$search_town=GETPOST('search_town','alpha');
$search_zip=GETPOST('search_zip','alpha');
$search_state=trim(GETPOST("search_state"));
$search_country=GETPOST("search_country",'int');
$search_type_thirdparty=GETPOST("search_type_thirdparty",'int');
$sall=trim((GETPOST('search_all', 'alphanohtml')!='')?GETPOST('search_all', 'alphanohtml'):GETPOST('sall', 'alphanohtml'));
$socid=GETPOST('socid','int');
$search_user=GETPOST('search_user','int');
$search_sale=GETPOST('search_sale','int');
$search_total_ht=GETPOST('search_total_ht','alpha');
$search_categ_cus=trim(GETPOST("search_categ_cus",'int'));
$optioncss = GETPOST('optioncss','alpha');
$billed = GETPOST('billed','int');
$viewstatut=GETPOST('viewstatut');
$search_btn=GETPOST('button_search','alpha');
$search_remove_btn=GETPOST('button_removefilter','alpha');
$search_project_ref=GETPOST('search_project_ref','alpha');

// Libre Expert 14/01/2019
$search_container_ref=GETPOST('search_container_ref','alpha');
$search_date_departure_container=GETPOST('search_date_departure_container','alpha');
$search_date_arrival_container=GETPOST('search_date_arrival_container','alpha');
$search_numpalette=GETPOST('search_numpalette','alpha');
$search_numcolis=GETPOST('search_numcolis','alpha');
$search_supplier_order=GETPOST('search_supplier_order','alpha');
$search_product_ref=GETPOST('search_product_ref','alpha');
$numpalette_modify_ref=GETPOST('numpalette_modify_ref','alpha');
$numcolis_modify_ref=GETPOST('numcolis_modify_ref','alpha');
$numcontainer_modify_ref=GETPOST('numcontainer_modify_ref','alpha');
$search_product_fournisseur_ref=GETPOST('search_product_fournisseur_ref','alpha');
//$arrivalcontainer_date_modify=GETPOST('arrivalcontainer_date_modify','alpha');
//$departurecontainer_date_modify=GETPOST('departurecontainer_date_modify','alpha');
// End Libre Expert

// Security check
$id = (GETPOST('orderid')?GETPOST('orderid','int'):GETPOST('id','int'));
if ($user->societe_id) $socid=$user->societe_id;
$result = restrictedArea($user, 'commande', $id,'');

$diroutputmassaction=$conf->commande->dir_output . '/temp/massgeneration/'.$user->id;

// Load variable for pagination
$limit = GETPOST('limit','int')?GETPOST('limit','int'):$conf->liste_limit;
$sortfield = GETPOST("sortfield",'alpha');
$sortorder = GETPOST("sortorder",'alpha');
$page = GETPOST("page",'int');
if (empty($page) || $page == -1 || !empty($search_btn) || !empty($search_remove_btn) || (empty($toselect) && $massaction === '0')) { $page = 0; }     // If $page is not defined, or '' or -1
$offset = $limit * $page;
$pageprev = $page - 1;
$pagenext = $page + 1;
if (! $sortfield) $sortfield='c.ref';
if (! $sortorder) $sortorder='DESC';

// Initialize technical object to manage hooks of page. Note that conf->hooks_modules contains array of hook context
$object = new Commande($db);
$hookmanager->initHooks(array('orderlist'));
$extrafields = new ExtraFields($db);

// fetch optionals attributes and labels
$extralabels = $extrafields->fetch_name_optionals_label('commande');
$search_array_options=$extrafields->getOptionalsFromPost($extralabels,'','search_');

// List of fields to search into when doing a "search in all"
$fieldstosearchall = array(
	'c.ref'=>'Ref',
	'c.ref_client'=>'RefCustomerOrder',
	'pd.description'=>'Description',
	's.nom'=>"ThirdParty",
	'c.note_public'=>'NotePublic',
);
if (empty($user->socid)) $fieldstosearchall["c.note_private"]="NotePrivate";

$checkedtypetiers=0;
$arrayfields=array(
	'c.ref'=>array('label'=>$langs->trans("Ref"), 'checked'=>1),
	'c.ref_client'=>array('label'=>$langs->trans("RefCustomerOrder"), 'checked'=>1),
	'p.project_ref'=>array('label'=>$langs->trans("ProjectRef"), 'checked'=>0, 'enabled'=>1),
	's.nom'=>array('label'=>$langs->trans("ThirdParty"), 'checked'=>1),
	's.town'=>array('label'=>$langs->trans("Town"), 'checked'=>1),
	's.zip'=>array('label'=>$langs->trans("Zip"), 'checked'=>1),
	'state.nom'=>array('label'=>$langs->trans("StateShort"), 'checked'=>0),
	'country.code_iso'=>array('label'=>$langs->trans("Country"), 'checked'=>0),
	'typent.code'=>array('label'=>$langs->trans("ThirdPartyType"), 'checked'=>$checkedtypetiers),
	'c.date_commande'=>array('label'=>$langs->trans("OrderDateShort"), 'checked'=>1),
	'c.date_delivery'=>array('label'=>$langs->trans("DateDeliveryPlanned"), 'checked'=>1, 'enabled'=>empty($conf->global->ORDER_DISABLE_DELIVERY_DATE)),
	'c.total_ht'=>array('label'=>$langs->trans("AmountHT"), 'checked'=>1),
	'c.total_vat'=>array('label'=>$langs->trans("AmountVAT"), 'checked'=>0),
	'c.total_ttc'=>array('label'=>$langs->trans("AmountTTC"), 'checked'=>0),
    
        // Libre Expert 14/01/2019
        'pde.numcoliscontainer'=>array('label'=>$langs->trans("NumeroColis"), 'checked'=>1),
        'pde.numpalettecontainer'=>array('label'=>$langs->trans("NumeroPalette"), 'checked'=>1),
        'pde.numpalettecontainer'=>array('label'=>$langs->trans("NumeroPalette"), 'checked'=>1),
        'pfp.ref_fourn'=>array('label'=>$langs->trans("RefProductFournisseur"), 'checked'=>1),
//        'cfe.numcontainer'=>array('label'=>$langs->trans("NumeroContainer"), 'checked'=>1),
//        'cfe.datedeparturecontainer'=>array('label'=>$langs->trans("DateDepartContainer"), 'checked'=>1),
//        'cfe.datearrivalcontainer'=>array('label'=>$langs->trans("DateArrivalContainer"), 'checked'=>1),
        'cont.ref'=>array('label'=>$langs->trans("NumeroContainer"), 'checked'=>1),
        'cont.datedeparturecontainer'=>array('label'=>$langs->trans("DateDepartContainer"), 'checked'=>1),
        'cont.datearrivalcontainer'=>array('label'=>$langs->trans("DateArrivalContainer"), 'checked'=>1),
        'cf.ref'=>array('label'=>$langs->trans("RefSupplierOrder"), 'checked'=>1),
        'pdct.ref'=>array('label'=>$langs->trans("RefProduct"), 'checked'=>1),

        //cfe.numcontainer, cfe.datedeparturecontainer, cfe.datearrivalcontainer
        //$search_container_ref='';
        //$search_date_arrival_container='';
        //$search_date_departure_container='';
        // End Libre Expert
    
	'c.datec'=>array('label'=>$langs->trans("DateCreation"), 'checked'=>0, 'position'=>500),
	'c.tms'=>array('label'=>$langs->trans("DateModificationShort"), 'checked'=>0, 'position'=>500),
	'c.fk_statut'=>array('label'=>$langs->trans("Status"), 'checked'=>1, 'position'=>1000),
	'c.facture'=>array('label'=>$langs->trans("Billed"), 'checked'=>1, 'position'=>1000, 'enabled'=>(empty($conf->global->WORKFLOW_BILL_ON_SHIPMENT)))
);
// Extra fields
if (is_array($extrafields->attribute_label) && count($extrafields->attribute_label))
{
	foreach($extrafields->attribute_label as $key => $val)
	{
		if (! empty($extrafields->attribute_list[$key])) $arrayfields["ef.".$key]=array('label'=>$extrafields->attribute_label[$key], 'checked'=>(($extrafields->attribute_list[$key]<0)?0:1), 'position'=>$extrafields->attribute_pos[$key], 'enabled'=>(abs($extrafields->attribute_list[$key])!=3 && $extrafields->attribute_perms[$key]));
	}
}



/*
 * Actions
 */

if (GETPOST('cancel','alpha')) { $action='list'; $massaction=''; }
if (! GETPOST('confirmmassaction','alpha') && $massaction != 'presend' && $massaction != 'confirm_presend' && $massaction != 'confirm_createbills'
        && $massaction !='confirm_modifycontainerref' // && $massaction !='confirm_modifycontainerdeparture' && $massaction !='confirm_modifycontainerarrival'
        && $massaction !='confirm_modifypalletref' && $massaction !='confirm_modifyparcelref') { $massaction=''; }

$parameters=array('socid'=>$socid);
$reshook=$hookmanager->executeHooks('doActions',$parameters,$object,$action);    // Note that $action and $object may have been modified by some hooks
if ($reshook < 0) setEventMessages($hookmanager->error, $hookmanager->errors, 'errors');

if (empty($reshook))
{
	// Selection of new fields
	include DOL_DOCUMENT_ROOT.'/core/actions_changeselectedfields.inc.php';

	// Purge search criteria
	if (GETPOST('button_removefilter_x','alpha') || GETPOST('button_removefilter.x','alpha') || GETPOST('button_removefilter','alpha')) // All tests are required to be compatible with all browsers
	{
		$search_categ='';
		$search_user='';
		$search_sale='';
		$search_product_category='';
		$search_ref='';
		$search_ref_customer='';
		$search_company='';
		$search_town='';
		$search_zip="";
		$search_state="";
		$search_type='';
		$search_country='';
		$search_type_thirdparty='';
		$search_total_ht='';
		$search_total_vat='';
		$search_total_ttc='';
		$search_orderyear='';
		$search_ordermonth='';
		$search_orderday='';
		$search_deliveryday='';
		$search_deliverymonth='';
		$search_deliveryyear='';
		$search_project_ref='';
		$viewstatut='';
		$billed='';
		$toselect='';
		$search_array_options=array();
		$search_categ_cus=0;
                
                // Libre Expert 14/01/2019
                $search_container_ref='';
                $search_date_arrival_container='';
                $search_date_departure_container='';
                $search_numpalette='';
                $search_numcolis='';
                $search_supplier_order='';
                $search_product_ref='';
                $search_product_fournisseur_ref='';
                // End Libre Expert
	}
	if (GETPOST('button_removefilter_x','alpha') || GETPOST('button_removefilter.x','alpha') || GETPOST('button_removefilter','alpha')
	 || GETPOST('button_search_x','alpha') || GETPOST('button_search.x','alpha') || GETPOST('button_search','alpha'))
	{
		$massaction='';     // Protection to avoid mass action if we force a new search during a mass action confirmation
	}

	// Mass actions
	$objectclass='Commande';
	$objectlabel='Orders';
	$permtoread = $user->rights->commande->lire;
	$permtodelete = $user->rights->commande->supprimer;
	$uploaddir = $conf->commande->dir_output;
	$trigger_name='ORDER_SENTBYMAIL';
	include DOL_DOCUMENT_ROOT.'/core/actions_massactions.inc.php';

}


/*
 * View
 */

$now=dol_now();

$form = new Form($db);
$formother = new FormOther($db);
$formfile = new FormFile($db);
$companystatic = new Societe($db);
$formcompany=new FormCompany($db);
$projectstatic=new Project($db);

$title=$langs->trans("OrdersGroupingAndSorting");
$help_url="EN:Module_Customers_Orders|FR:Module_Commandes_Clients|ES:Módulo_Pedidos_de_clientes";
llxHeader('',$title,$help_url);

/* Libre Expert 14/01/2019 -- Requête générée par l'outil export
SELECT DISTINCT s.rowid as s_rowid, s.nom as s_nom, s.address as s_address, s.zip as s_zip, s.town as s_town, co.label as co_label, co.code as co_code, s.phone as s_phone,
c.rowid as c_rowid, c.ref as c_ref, c.ref_client as c_ref_client, c.fk_soc as c_fk_soc, c.date_creation as c_date_creation, c.date_commande as c_date_commande,
c.date_livraison as c_date_livraison, c.amount_ht as c_amount_ht, c.total_ht as c_total_ht, c.total_ttc as c_total_ttc, c.facture as c_facture, c.fk_statut as c_fk_statut,
c.note_public as c_note_public, c.fk_user_author as c_fk_user_author, uv.login as uv_login, cd.rowid as cd_rowid, cd.label as cd_label, cd.description as cd_description,
cd.tva_tx as cd_tva_tx, cd.qty as cd_qty, cd.total_ht as cd_total_ht, cd.total_tva as cd_total_tva, cd.total_ttc as cd_total_ttc, p.rowid as p_rowid, p.ref as p_ref,
p.label as p_label, extra2.numpalettecontainer as extra2_numpalettecontainer, extra2.numcoliscontainer as extra2_numcoliscontainer, extra3.ecotaxdeee as extra3_ecotaxdeee
FROM llx_societe as s 
LEFT JOIN llx_c_departements as d ON s.fk_departement = d.rowid LEFT JOIN llx_c_country as co ON s.fk_pays = co.rowid, llx_commande as c 
LEFT JOIN llx_projet as pj ON c.fk_projet = pj.rowid LEFT JOIN llx_user as uc ON c.fk_user_author = uc.rowid LEFT JOIN llx_user as uv ON c.fk_user_valid = uv.rowid 
LEFT JOIN llx_commande_extrafields as extra ON c.rowid = extra.fk_object , llx_commandedet as cd LEFT JOIN llx_commandedet_extrafields as extra2 on cd.rowid = extra2.fk_object 
LEFT JOIN llx_product as p on cd.fk_product = p.rowid LEFT JOIN llx_product_extrafields as extra3 on p.rowid = extra3.fk_object 
WHERE c.fk_soc = s.rowid AND c.rowid = cd.fk_commande AND c.entity IN (1)
 */



$sql = 'SELECT DISTINCT';
if ($sall || $search_product_category > 0) $sql = 'SELECT DISTINCT';
$sql.= ' s.rowid as socid, s.nom as name, s.email, s.town, s.zip, s.fk_pays, s.client, s.code_client,';
$sql.= " typent.code as typent_code,";
$sql.= " state.code_departement as state_code, state.nom as state_name,";
$sql.= ' c.rowid, c.ref, c.total_ht, c.tva as total_tva, c.total_ttc, c.ref_client,';
$sql.= ' c.date_valid, c.date_commande, c.note_private, c.date_livraison as date_delivery, c.fk_statut, c.facture as billed,';
$sql.= ' c.date_creation as date_creation, c.tms as date_update,';
$sql.= " p.rowid as project_id, p.ref as project_ref";

// Libre Expert 14/01/2019
$sql.= ', pdct.ref as product_ref, pdct.rowid as product_rowid, pdct.label as product_label , pde.rowid as order_element_extra_rowid, pde.numpalettecontainer, pde.numcoliscontainer, pd.rowid as order_element_rowid'
        . ', cf.ref as commande_fournisseur_ref, cf.rowid as commande_fournisseur_rowid, cont.rowid as container_rowid, cont.ref as numcontainer, cont.datedeparturecontainer, cont.datearrivalcontainer, pfp.ref_fourn';
// End Libre Expert

if ($search_categ_cus) $sql .= ", cc.fk_categorie, cc.fk_soc";

// Add fields from extrafields
foreach ($extrafields->attribute_label as $key => $val) $sql.=($extrafields->attribute_type[$key] != 'separate' ? ",ef.".$key.' as options_'.$key : '');
// Add fields from hooks
$parameters=array();
$reshook=$hookmanager->executeHooks('printFieldListSelect',$parameters);    // Note that $action and $object may have been modified by hook
$sql.=$hookmanager->resPrint;
$sql.= ' FROM '.MAIN_DB_PREFIX.'societe as s';
$sql.= " LEFT JOIN ".MAIN_DB_PREFIX."c_country as country on (country.rowid = s.fk_pays)";
$sql.= " LEFT JOIN ".MAIN_DB_PREFIX."c_typent as typent on (typent.id = s.fk_typent)";
$sql.= " LEFT JOIN ".MAIN_DB_PREFIX."c_departements as state on (state.rowid = s.fk_departement)";
if (! empty($search_categ_cus)) $sql.= ' LEFT JOIN '.MAIN_DB_PREFIX."categorie_societe as cc ON s.rowid = cc.fk_soc"; // We'll need this table joined to the select in order to filter by categ
$sql.= ', '.MAIN_DB_PREFIX.'commande as c';
if (is_array($extrafields->attribute_label) && count($extrafields->attribute_label)) $sql.= " LEFT JOIN ".MAIN_DB_PREFIX."commande_extrafields as ef on (c.rowid = ef.fk_object)";


// Libre Expert 14/01/2019
//if ($sall || $search_product_category > 0) $sql.= ' LEFT JOIN '.MAIN_DB_PREFIX.'commandedet as pd ON c.rowid=pd.fk_commande';
//if ($search_product_category > 0) $sql.= ' LEFT JOIN '.MAIN_DB_PREFIX.'categorie_product as cp ON cp.fk_product=pd.fk_product';
$sql.= ' LEFT JOIN '.MAIN_DB_PREFIX.'commandedet as pd ON c.rowid=pd.fk_commande';
$sql.= ' LEFT JOIN '.MAIN_DB_PREFIX.'categorie_product as cp ON cp.fk_product=pd.fk_product';
$sql.= ' LEFT JOIN '.MAIN_DB_PREFIX.'product as pdct ON pdct.rowid=pd.fk_product';
$sql.= ' LEFT JOIN '.MAIN_DB_PREFIX.'commandedet_extrafields as pde ON pd.rowid = pde.fk_object';
$sql.= ' LEFT JOIN '.MAIN_DB_PREFIX.'element_element as ee ON ee.fk_source = c.rowid AND ee.sourcetype=\'commande\' AND ee.targettype=\'order_supplier\'';
$sql.= ' LEFT JOIN '.MAIN_DB_PREFIX.'commande_fournisseur as cf ON ee.fk_target = cf.rowid AND ee.sourcetype=\'commande\' AND ee.targettype=\'order_supplier\'';
$sql.= ' LEFT JOIN '.MAIN_DB_PREFIX.'commande_fournisseur_extrafields as cfe ON cf.rowid = cfe.fk_object';
$sql.= ' LEFT JOIN '.MAIN_DB_PREFIX.'containermanagement_container as cont ON cfe.fk_id_container = cont.rowid';
$sql.= ' LEFT JOIN '.MAIN_DB_PREFIX.'product_fournisseur_price as pfp ON pfp.fk_product=pd.fk_product AND pfp.fk_soc=cf.fk_soc';

// End Libre Expert

$sql.= " LEFT JOIN ".MAIN_DB_PREFIX."projet as p ON p.rowid = c.fk_projet";
// We'll need this table joined to the select in order to filter by sale
if ($search_sale > 0 || (! $user->rights->societe->client->voir && ! $socid)) $sql .= ", ".MAIN_DB_PREFIX."societe_commerciaux as sc";
if ($search_user > 0)
{
	$sql.=", ".MAIN_DB_PREFIX."element_contact as ec";
	$sql.=", ".MAIN_DB_PREFIX."c_type_contact as tc";
}
$sql.= ' WHERE c.fk_soc = s.rowid';
$sql.= ' AND c.entity IN ('.getEntity('commande').')';
if ($search_product_category > 0) $sql.=" AND cp.fk_categorie = ".$search_product_category;
if ($socid > 0) $sql.= ' AND s.rowid = '.$socid;
if (!$user->rights->societe->client->voir && !$socid) $sql.= " AND s.rowid = sc.fk_soc AND sc.fk_user = " .$user->id;
if ($search_ref) $sql .= natural_search('c.ref', $search_ref);
if ($search_ref_customer) $sql.= natural_search('c.ref_client', $search_ref_customer);
if ($sall) $sql .= natural_search(array_keys($fieldstosearchall), $sall);
if ($billed != '' && $billed >= 0) $sql.=' AND c.facture = '.$billed;
if ($viewstatut <> '')
{
	if ($viewstatut < 4 && $viewstatut > -3)
	{
		if ($viewstatut == 1 && empty($conf->expedition->enabled)) $sql.= ' AND c.fk_statut IN (1,2)';	// If module expedition disabled, we include order with status 'sending in process' into 'validated'
		else $sql.= ' AND c.fk_statut = '.$viewstatut; // brouillon, validee, en cours, annulee
	}
	if ($viewstatut == 4)
	{
		$sql.= ' AND c.facture = 1'; // invoice created
	}
	if ($viewstatut == -2)	// To process
	{
		//$sql.= ' AND c.fk_statut IN (1,2,3) AND c.facture = 0';
		$sql.= " AND ((c.fk_statut IN (1,2)) OR (c.fk_statut = 3 AND c.facture = 0))";    // If status is 2 and facture=1, it must be selected
	}
	if ($viewstatut == -3)	// To bill
	{
		//$sql.= ' AND c.fk_statut in (1,2,3)';
		//$sql.= ' AND c.facture = 0'; // invoice not created
		$sql .= ' AND ((c.fk_statut IN (1,2)) OR (c.fk_statut = 3 AND c.facture = 0))'; // validated, in process or closed but not billed
	}
}
if ($search_ordermonth > 0)
{
	if ($search_orderyear > 0 && empty($search_orderday))
	$sql.= " AND c.date_commande BETWEEN '".$db->idate(dol_get_first_day($search_orderyear,$search_ordermonth,false))."' AND '".$db->idate(dol_get_last_day($search_orderyear,$search_ordermonth,false))."'";
	else if ($search_orderyear > 0 && ! empty($search_orderday))
	$sql.= " AND c.date_commande BETWEEN '".$db->idate(dol_mktime(0, 0, 0, $search_ordermonth, $search_orderday, $search_orderyear))."' AND '".$db->idate(dol_mktime(23, 59, 59, $search_ordermonth, $search_orderday, $search_orderyear))."'";
	else
	$sql.= " AND date_format(c.date_commande, '%m') = '".$search_ordermonth."'";
}
else if ($search_orderyear > 0)
{
	$sql.= " AND c.date_commande BETWEEN '".$db->idate(dol_get_first_day($search_orderyear,1,false))."' AND '".$db->idate(dol_get_last_day($search_orderyear,12,false))."'";
}
if ($search_deliverymonth > 0)
{
	if ($search_deliveryyear > 0 && empty($search_deliveryday))
	$sql.= " AND c.date_livraison BETWEEN '".$db->idate(dol_get_first_day($search_deliveryyear,$search_deliverymonth,false))."' AND '".$db->idate(dol_get_last_day($search_deliveryyear,$search_deliverymonth,false))."'";
	else if ($search_deliveryyear > 0 && ! empty($search_deliveryday))
	$sql.= " AND c.date_livraison BETWEEN '".$db->idate(dol_mktime(0, 0, 0, $search_deliverymonth, $search_deliveryday, $search_deliveryyear))."' AND '".$db->idate(dol_mktime(23, 59, 59, $search_deliverymonth, $search_deliveryday, $search_deliveryyear))."'";
	else
	$sql.= " AND date_format(c.date_livraison, '%m') = '".$search_deliverymonth."'";
}
else if ($search_deliveryyear > 0)
{
	$sql.= " AND c.date_livraison BETWEEN '".$db->idate(dol_get_first_day($search_deliveryyear,1,false))."' AND '".$db->idate(dol_get_last_day($search_deliveryyear,12,false))."'";
}
if ($search_town)  $sql.= natural_search('s.town', $search_town);
if ($search_zip)   $sql.= natural_search("s.zip",$search_zip);
if ($search_state) $sql.= natural_search("state.nom",$search_state);
if ($search_country) $sql .= " AND s.fk_pays IN (".$search_country.')';
if ($search_type_thirdparty) $sql .= " AND s.fk_typent IN (".$search_type_thirdparty.')';
if ($search_company) $sql .= natural_search('s.nom', $search_company);
if ($search_sale > 0) $sql.= " AND s.rowid = sc.fk_soc AND sc.fk_user = " .$search_sale;
if ($search_user > 0) $sql.= " AND ec.fk_c_type_contact = tc.rowid AND tc.element='commande' AND tc.source='internal' AND ec.element_id = c.rowid AND ec.fk_socpeople = ".$search_user;
if ($search_total_ht != '') $sql.= natural_search('c.total_ht', $search_total_ht, 1);

// Libre Expert 15/01/2018
if ($search_numpalette != '') $sql.= " AND pde.numpalettecontainer LIKE '%" . $search_numpalette ."%'";
if ($search_numcolis != '') $sql.= " AND pde.numcoliscontainer LIKE '%" . $search_numcolis ."%'";
if ($search_container_ref != '') $sql.= " AND cont.ref LIKE '%" . $search_container_ref ."%'";
if ($search_date_departure_container != '') $sql.= " AND DATE_FORMAT(cont.datedeparturecontainer, '%d/%m/%Y') LIKE '%" . $search_date_departure_container ."%'";
if ($search_date_arrival_container != '') $sql.= " AND DATE_FORMAT(cont.datearrivalcontainer, '%d/%m/%Y') LIKE '%" . $search_date_arrival_container ."%'";
if ($search_supplier_order != '') $sql.= " AND cf.ref LIKE '%" . $search_supplier_order ."%'";
if ($search_product_ref != '') $sql.= " AND pdct.ref LIKE '%" . $search_product_ref ."%'";
if ($search_product_fournisseur_ref != '') $sql.= " AND pfp.ref_fourn LIKE '%" . $search_product_fournisseur_ref ."%'";
//$search_supplier_order
//$search_product_ref
// End Libre Expert
//cfe.numcontainer, cfe.datedeparturecontainer, cfe.datearrivalcontainer
//$search_container_ref='';
//$search_date_arrival_container='';
//$search_date_departure_container='';

if ($search_project_ref != '') $sql.= natural_search("p.ref",$search_project_ref);
if ($search_categ_cus > 0) $sql.= " AND cc.fk_categorie = ".$db->escape($search_categ_cus);
if ($search_categ_cus == -2)   $sql.= " AND cc.fk_categorie IS NULL";
// Add where from extra fields
include DOL_DOCUMENT_ROOT.'/core/tpl/extrafields_list_search_sql.tpl.php';
// Add where from hooks
$parameters=array();
$reshook=$hookmanager->executeHooks('printFieldListWhere',$parameters);    // Note that $action and $object may have been modified by hook
$sql.=$hookmanager->resPrint;

$sql.= $db->order($sortfield,$sortorder);

// Count total nb of records
$nbtotalofrecords = '';
if (empty($conf->global->MAIN_DISABLE_FULL_SCANLIST))
{
	$result = $db->query($sql);
	$nbtotalofrecords = $db->num_rows($result);

	if (($page * $limit) > $nbtotalofrecords)	// if total resultset is smaller then paging size (filtering), goto and load page 0
	{
		$page = 0;
		$offset = 0;
	}
}

$sql.= $db->plimit($limit + 1,$offset);
//print $sql;

$resql = $db->query($sql);
if ($resql)
{
	if ($socid > 0)
	{
		$soc = new Societe($db);
		$soc->fetch($socid);
		$title = $langs->trans('OrdersGroupingAndSorting') . ' - '.$soc->name;
		if (empty($search_company)) $search_company = $soc->name;
	}
	else
	{
		$title = $langs->trans('OrdersGroupingAndSorting');
	}
	if (strval($viewstatut) == '0')
	$title.=' - '.$langs->trans('StatusOrderDraftShort');
	if ($viewstatut == 1)
	$title.=' - '.$langs->trans('StatusOrderValidatedShort');
	if ($viewstatut == 2)
	$title.=' - '.$langs->trans('StatusOrderSentShort');
	if ($viewstatut == 3)
	$title.=' - '.$langs->trans('StatusOrderToBillShort');
	if ($viewstatut == 4)
	$title.=' - '.$langs->trans('StatusOrderProcessedShort');
	if ($viewstatut == -1)
	$title.=' - '.$langs->trans('StatusOrderCanceledShort');
	if ($viewstatut == -2)
	$title.=' - '.$langs->trans('StatusOrderToProcessShort');
	if ($viewstatut == -3)
	$title.=' - '.$langs->trans('StatusOrderValidated').', '.(empty($conf->expedition->enabled)?'':$langs->trans("StatusOrderSent").', ').$langs->trans('StatusOrderToBill');

	$num = $db->num_rows($resql);

	$arrayofselected=is_array($toselect)?$toselect:array();

	$param='';

	if (! empty($contextpage) && $contextpage != $_SERVER["PHP_SELF"]) $param.='&contextpage='.urlencode($contextpage);
	if ($limit > 0 && $limit != $conf->liste_limit) $param.='&limit='.urlencode($limit);
	if ($sall)					$param.='&sall='.urlencode($sall);
	if ($socid > 0)             $param.='&socid='.urlencode($socid);
	if ($viewstatut != '')      $param.='&viewstatut='.urlencode($viewstatut);
	if ($search_orderday)      		$param.='&search_orderday='.urlencode($search_orderday);
	if ($search_ordermonth)      		$param.='&search_ordermonth='.urlencode($search_ordermonth);
	if ($search_orderyear)       		$param.='&search_orderyear='.urlencode($search_orderyear);
	if ($search_deliveryday)   		$param.='&search_deliveryday='.urlencode($search_deliveryday);
	if ($search_deliverymonth)   		$param.='&search_deliverymonth='.urlencode($search_deliverymonth);
	if ($search_deliveryyear)    		$param.='&search_deliveryyear='.urlencode($search_deliveryyear);
	if ($search_ref)      		$param.='&search_ref='.urlencode($search_ref);
	if ($search_company)  		$param.='&search_company='.urlencode($search_company);
	if ($search_ref_customer)	$param.='&search_ref_customer='.urlencode($search_ref_customer);
	if ($search_user > 0) 		$param.='&search_user='.urlencode($search_user);
	if ($search_sale > 0) 		$param.='&search_sale='.urlencode($search_sale);
	if ($search_total_ht != '') $param.='&search_total_ht='.urlencode($search_total_ht);
	if ($search_total_vat != '')  $param.='&search_total_vat='.urlencode($search_total_vat);
	if ($search_total_ttc != '')  $param.='&search_total_ttc='.urlencode($search_total_ttc);
        
        // Libre Expert 15/01/2019
        if ($search_numpalette != '')  $param.='&search_numpalette='.urlencode($search_numpalette);
        if ($search_numcolis != '')  $param.='&search_numcolis='.urlencode($search_numcolis);
        if ($search_container_ref != '')  $param.='&search_container_ref='.urlencode($search_container_ref);
        if ($search_date_arrival_container != '')  $param.='&search_date_arrival_container='.urlencode($search_date_arrival_container);
        if ($search_date_departure_container != '')  $param.='&search_date_departure_container='.urlencode($search_date_departure_container);
        if ($search_supplier_order != '') $param.= '&search_supplier_order='.urlencode($search_supplier_order);
        if ($search_product_ref != '') $param.= '&search_product_ref='.urlencode($search_product_ref);
        if ($search_product_fournisseur_ref != '') $param.= '&search_product_fournisseur_ref='.urlencode($search_product_fournisseur_ref);
        //cfe.numcontainer, cfe.datedeparturecontainer, cfe.datearrivalcontainer
        //$search_container_ref='';
        //$search_date_arrival_container='';
        //$search_date_departure_container='';
        // End Libre Expert
        
	if ($search_project_ref >= 0) $param.="&search_project_ref=".urlencode($search_project_ref);
	if ($search_town != '')       $param.='&search_town='.urlencode($search_town);
	if ($search_zip != '')        $param.='&search_zip='.urlencode($search_zip);
	if ($search_state != '')      $param.='&search_state='.urlencode($search_state);
	if ($search_country != '')    $param.='&search_country='.urlencode($search_country);
	if ($search_type_thirdparty != '')  $param.='&search_type_thirdparty='.urlencode($search_type_thirdparty);
	if ($search_product_category != '') $param.='&search_product_category='.urlencode($search_product_category);
	if ($search_categ_cus > 0)          $param.='&search_categ_cus='.urlencode($search_categ_cus);
	if ($show_files)            $param.='&show_files=' .urlencode($show_files);
	if ($optioncss != '')       $param.='&optioncss='.urlencode($optioncss);
	if ($billed != '')			$param.='&billed='.urlencode($billed);

	// Add $param from extra fields
	include DOL_DOCUMENT_ROOT.'/core/tpl/extrafields_list_search_param.tpl.php';

	// List of mass actions available
	$arrayofmassactions =  array(
	//	'presend'=>$langs->trans("SendByMail"),
	//	'builddoc'=>$langs->trans("PDFMerge"),
	//	'cancelorders'=>$langs->trans("CancelOrders"),
                'pickinglist'=>$langs->trans("PickingList"),
                'modifypalletref'=>$langs->trans("ModifyPalletRef"),
                'modifyparcelref'=>$langs->trans("ModifyParcelRef"),
                'modifycontainerref'=>$langs->trans("ModifyContainerRef"),
        //        'modifycontainerdeparture'=>$langs->trans("ModifyContainerDeparture"),
        //        'modifycontainerarrival'=>$langs->trans("ModifyContainerArrival"),

	);
//	if($user->rights->facture->creer) $arrayofmassactions['createbills']=$langs->trans("CreateInvoiceForThisCustomer");
//	if ($user->rights->commande->supprimer) $arrayofmassactions['predelete']=$langs->trans("Delete");
//	if (in_array($massaction, array('presend','predelete','createbills','modifypalletref','modifyparcelref',
//            'modifycontainerref','modifycontainerdeparture','modifycontainerarrival'))) $arrayofmassactions=array();
        if (in_array($massaction, array('presend','predelete','createbills','modifypalletref','modifyparcelref',
            'modifycontainerref'))) $arrayofmassactions=array();

	$massactionbutton=$form->selectMassAction('', $arrayofmassactions);

	$newcardbutton='';
	if ($contextpage == 'orderlist' && $user->rights->commande->creer)
	{
		$newcardbutton='<a class="butActionNew" href="'.DOL_URL_ROOT.'/commande/card.php?action=create"><span class="valignmiddle">'.$langs->trans('NewOrder').'</span>';
		$newcardbutton.= '<span class="fa fa-plus-circle valignmiddle"></span>';
		$newcardbutton.= '</a>';
	}

	// Lines of title fields
	print '<form method="POST" id="searchFormList" action="'.$_SERVER["PHP_SELF"].'">';
	if ($optioncss != '') print '<input type="hidden" name="optioncss" value="'.$optioncss.'">';
	print '<input type="hidden" name="token" value="'.$_SESSION['newtoken'].'">';
	print '<input type="hidden" name="formfilteraction" id="formfilteraction" value="list">';
	print '<input type="hidden" name="action" value="list">';
	print '<input type="hidden" name="sortfield" value="'.$sortfield.'">';
	print '<input type="hidden" name="sortorder" value="'.$sortorder.'">';
	print '<input type="hidden" name="page" value="'.$page.'">';
	print '<input type="hidden" name="contextpage" value="'.$contextpage.'">';
	print '<input type="hidden" name="viewstatut" value="'.$viewstatut.'">';
	print '<input type="hidden" name="socid" value="'.$socid.'">';


	print_barre_liste($title, $page, $_SERVER["PHP_SELF"], $param, $sortfield, $sortorder, $massactionbutton, $num, $nbtotalofrecords, 'title_commercial.png', 0, $newcardbutton, '', $limit);

	$topicmail="SendOrderRef";
	$modelmail="order_send";
	$objecttmp=new Commande($db);
	$trackid='ord'.$object->id;
	include DOL_DOCUMENT_ROOT.'/core/tpl/massactions_pre.tpl.php';

	if ($massaction == 'createbills')
	{
		//var_dump($_REQUEST);
		print '<input type="hidden" name="massaction" value="confirm_createbills">';

		print '<table class="noborder" width="100%" >';
		print '<tr>';
		print '<td class="titlefield">';
		print $langs->trans('DateInvoice');
		print '</td>';
		print '<td>';
		print $form->select_date('', '', '', '', '', '', 1, 1);
		print '</td>';
		print '</tr>';
		print '<tr>';
		print '<td>';
		print $langs->trans('CreateOneBillByThird');
		print '</td>';
		print '<td>';
		print $form->selectyesno('createbills_onebythird', '', 1);
		print '</td>';
		print '</tr>';
		print '<tr>';
		print '<td>';
		print $langs->trans('ValidateInvoices');
		print '</td>';
		print '<td>';
		if (! empty($conf->stock->enabled) && ! empty($conf->global->STOCK_CALCULATE_ON_BILL))
		{
			print $form->selectyesno('valdate_invoices', 0, 1, 1);
			print ' ('.$langs->trans("AutoValidationNotPossibleWhenStockIsDecreasedOnInvoiceValidation").')';
		}
		else
		{
			print $form->selectyesno('valdate_invoices', 0, 1);
		}
		if (! empty($conf->workflow->enabled) && ! empty($conf->global->WORKFLOW_INVOICE_AMOUNT_CLASSIFY_BILLED_ORDER)) print ' &nbsp; &nbsp; <span class="opacitymedium">'.$langs->trans("IfValidateInvoiceIsNoOrderStayUnbilled").'</span>';
		else print ' &nbsp; &nbsp; <span class="opacitymedium">'.$langs->trans("OptionToSetOrderBilledNotEnabled").'</span>';
		print '</td>';
		print '</tr>';
		print '</table>';

		print '<br>';
		print '<div class="center">';
		print '<input type="submit" class="button" id="createbills" name="createbills" value="'.$langs->trans('CreateInvoiceForThisCustomer').'">  ';
		print '<input type="submit" class="button" id="cancel" name="cancel" value="'.$langs->trans('Cancel').'">';
		print '</div>';
		print '<br>';
	}
        
        if ($massaction == 'pickinglist')
	{
            //print '<input type="hidden" name="massaction" value="pickinglist">';
            //print_r($arrayofselected);
            include_once __DIR__ . '/lib/commandepdf.lib.php';
            //include_once DOL_DOCUMENT_ROOT .'/core/lib/commandepdf.lib.php';
            
            $output = array();
            $listecommandes = array();
            
            foreach($arrayofselected as $term){
              $output[] = $term;
            }
            dol_syslog('implode selected order elements : '. implode(', ', $output));
            
            $pickresql = $db->query('SELECT fk_commande FROM '.MAIN_DB_PREFIX.'commandedet as cd WHERE cd.rowid IN ('. implode(', ', $output) .')');
            
            $numrows = $db->num_rows($pickresql);
            
            $i=0;
            
            if ($pickresql) {
                while ($i < $numrows) {
                    $pickobj = $db->fetch_object($pickresql);
                    $listecommandes[] = $pickobj->fk_commande;
                    $i++;
                }
            }
//            print_r($orderlist);
//            foreach ($orderlist as $orderline) {
//                $listecommandes[] = $orderline->fk_commande;
//            }
            //print_r($listecommandes);
            rebuild_merge_commandes_pdf($db, $listecommandes, $langs, $conf, $diroutputmassaction, 0, 1, 'commandes', 'pickinglist');
            //rebuild_merge_commandes_pdf($db, $arrayofselected, $langs, $conf, $conf->commande->dir_output . '/pickinglists',1, 1, 'merge', 'pickinglist');
            $db->free($pickresql);
            //free selection
            //$arrayofselected = array();
            
        }
        
        if ($massaction == 'modifypalletref' || $massaction == 'confirm_modifypalletref')
	{
            dol_syslog("modification numéro palette massaction : " . $massaction);
            
            if ($massaction == 'modifypalletref') {
		print '<input type="hidden" name="massaction" value="confirm_modifypalletref">';

		print '<table class="noborder" width="100%" >';
		print '<tr>';
		print '<td class="titlefield">';
		print $langs->trans('NumeroPalette');
		print '</td>';
		print '<td>';
		print '<input class="flat" size="40" type="text" name="numpalette_modify_ref" value="">';
		print '</td>';
		print '</tr>';
		print '</table>';

		print '<br>';
		print '<div class="center">';
		print '<input type="submit" class="button" id="modifypallet" name="modifypallet" value="'.$langs->trans('ModifyPalletRef').'">  ';
		print '<input type="submit" class="button" id="cancel" name="cancel" value="'.$langs->trans('Cancel').'">';
		print '</div>';
		print '<br>';
            } else {
                dol_syslog("modification numéro palette count: " . count($arrayofselected), LOG_DEBUG);
                foreach($arrayofselected as $orderelementid) {
                    //$sql = 'UPDATE '.MAIN_DB_PREFIX.'commandedet_extrafields as cde INNER JOIN '.MAIN_DB_PREFIX.'commandedet cd ON cd.rowid = cde.fk_object '
                    //       . ' SET cde.numpalettecontainer = \''. $numpalette_modify_ref .'\' WHERE cd.rowid = '.$orderelementid;
                    //order_element_extra_rowid
                    $orderresql = $db->query('SELECT rowid FROM '.MAIN_DB_PREFIX.'commandedet_extrafields as cde WHERE cde.fk_object = '.$orderelementid);
                    
                    $objcount = $db->num_rows($orderresql);
                    dol_syslog("modification numéro palette objcount: " . $objcount, LOG_DEBUG);
                    if ($objcount > 0) {
                        $palettsql = 'UPDATE '.MAIN_DB_PREFIX.'commandedet_extrafields as cde SET cde.numpalettecontainer = \''. $numpalette_modify_ref .'\' WHERE cde.fk_object = '.$orderelementid;
                    } else {
                        $palettsql = 'INSERT INTO '.MAIN_DB_PREFIX.'commandedet_extrafields (fk_object, numpalettecontainer) VALUES('.$orderelementid.',\''. $numpalette_modify_ref .'\')';
                    }
                    
                    $palettresql = $db->query($palettsql);
                    
                    $db->free($orderresql);
                    $db->free($palettresql);
                    dol_syslog("modification numéro palette : " . $palettsql, LOG_DEBUG);
                    
                }
                // Regeneration of full list
                $db->free($resql);
                $resql = $db->query($sql);
                //free selection
                //$arrayofselected = array();
            }
	}
        
        if ($massaction == 'modifyparcelref' || $massaction == 'confirm_modifyparcelref')
	{
            dol_syslog("modification numéro colis massaction : " . $massaction);
            
            if ($massaction == 'modifyparcelref') {
		print '<input type="hidden" name="massaction" value="confirm_modifyparcelref">';

		print '<table class="noborder" width="100%" >';
		print '<tr>';
		print '<td class="titlefield">';
		print $langs->trans('NumeroColis');
		print '</td>';
		print '<td>';
		print '<input class="flat" size="40" type="text" name="numcolis_modify_ref" value="">';
		print '</td>';
		print '</tr>';
		print '</table>';

		print '<br>';
		print '<div class="center">';
		print '<input type="submit" class="button" id="modifyparcel" name="modifyparcel" value="'.$langs->trans('ModifyParcelRef').'">  ';
		print '<input type="submit" class="button" id="cancel" name="cancel" value="'.$langs->trans('Cancel').'">';
		print '</div>';
		print '<br>';
            } else {
                dol_syslog("modification numéro colis count: " . count($arrayofselected), LOG_DEBUG);
                foreach($arrayofselected as $orderelementid) {
                    //$sql = 'UPDATE '.MAIN_DB_PREFIX.'commandedet_extrafields as cde INNER JOIN '.MAIN_DB_PREFIX.'commandedet cd ON cd.rowid = cde.fk_object '
                    //       . ' SET cde.numpalettecontainer = \''. $numpalette_modify_ref .'\' WHERE cd.rowid = '.$orderelementid;
                    //order_element_extra_rowid
                    $orderresql = $db->query('SELECT rowid FROM '.MAIN_DB_PREFIX.'commandedet_extrafields as cde WHERE cde.fk_object = '.$orderelementid);
                    
                    $objcount = $db->num_rows($orderresql);
                    dol_syslog("modification numéro colis objcount: " . $objcount, LOG_DEBUG);
                    if ($objcount > 0) {
                        $colissql = 'UPDATE '.MAIN_DB_PREFIX.'commandedet_extrafields as cde SET cde.numcoliscontainer = \''. $numcolis_modify_ref .'\' WHERE cde.fk_object = '.$orderelementid;
                    } else {
                        $colissql = 'INSERT INTO '.MAIN_DB_PREFIX.'commandedet_extrafields (fk_object, numcoliscontainer) VALUES('.$orderelementid.',\''. $numcolis_modify_ref .'\')';
                    }
                    
                    $colisresql = $db->query($colissql);
                    
                    $db->free($orderresql);
                    $db->free($colisresql);
                    dol_syslog("modification numéro colis : " . $colissql, LOG_DEBUG);
                    
                }
                // Regeneration of full list
                $db->free($resql);
                $resql = $db->query($sql);
                //free selection
                //$arrayofselected = array();
            }
	}
        
        if ($massaction == 'modifycontainerref' || $massaction == 'confirm_modifycontainerref')
	{
            dol_syslog("modification numéro container massaction : " . $massaction);
            
            if ($massaction == 'modifycontainerref') {
		print '<input type="hidden" name="massaction" value="confirm_modifycontainerref">';

		print '<table class="noborder" width="100%" >';
		print '<tr>';
		print '<td class="titlefield">';
		print $langs->trans('NumeroContainer');
		print '</td>';
		print '<td>';
		//print '<input class="flat" size="8" type="text" name="numcontainer_modify_ref" value="">';
                print $form->selectForForms('Container:/containermanagement/class/container.class.php', 'numcontainer_modify_ref', 1, 'Pas de containers');
		print '</td>';
		print '</tr>';
		print '</table>';

		print '<br>';
		print '<div class="center">';
		print '<input type="submit" class="button" id="modifycontainer" name="modifycontainer" value="'.$langs->trans('ModifyContainerRef').'">  ';
		print '<input type="submit" class="button" id="cancel" name="cancel" value="'.$langs->trans('Cancel').'">';
		print '</div>';
		print '<br>';
            } else {
                dol_syslog("modification numéro container count: " . count($arrayofselected), LOG_DEBUG);
                foreach($arrayofselected as $orderelementid) {
                    //$sql = 'UPDATE '.MAIN_DB_PREFIX.'commandedet_extrafields as cde INNER JOIN '.MAIN_DB_PREFIX.'commandedet cd ON cd.rowid = cde.fk_object '
                    //       . ' SET cde.numpalettecontainer = \''. $numpalette_modify_ref .'\' WHERE cd.rowid = '.$orderelementid;
                    //order_element_extra_rowid
                    // Container
                    $containersql = 'SELECT DISTINCT cfe.rowid FROM '.MAIN_DB_PREFIX.'commande_fournisseur_extrafields,'.MAIN_DB_PREFIX.'commande as c';
                    $containersql.= ' LEFT JOIN '.MAIN_DB_PREFIX.'element_element as ee ON ee.fk_source = c.rowid AND ee.sourcetype=\'commande\' AND ee.targettype=\'order_supplier\'';
                    $containersql.= ' LEFT JOIN '.MAIN_DB_PREFIX.'commande_fournisseur as cf ON ee.fk_target = cf.rowid AND ee.sourcetype=\'commande\' AND ee.targettype=\'order_supplier\'';
                    $containersql.= ' LEFT JOIN '.MAIN_DB_PREFIX.'commande_fournisseur_extrafields as cfe ON cf.rowid = cfe.fk_object';
                    //$containersql.= ' LEFT JOIN '.MAIN_DB_PREFIX.'containermanagement_container as cont ON cfe.fk_id_container = cont.rowid';
                    $containersql.= ' LEFT JOIN '.MAIN_DB_PREFIX.'commandedet as cd ON cd.fk_commande = c.rowid WHERE cd.rowid = '.$orderelementid . ' AND cfe.rowid IS NOT NULL';
                    dol_syslog("containersql from list_commande_tri_regroupement numero : " . $containersql);
                    
                    $containerressql = $db->query($containersql);
                    
                    $objcount = $db->num_rows($containerressql);
                    dol_syslog("modification numéro container objcount: " . $objcount, LOG_DEBUG);
                    if ($objcount > 0) {
                        $containerobj = $db->fetch_object($containerressql);
                        $rowidcontainer = $containerobj->rowid;
                        $containerupsql = 'UPDATE '.MAIN_DB_PREFIX.'commande_fournisseur_extrafields as cfe SET cfe.fk_id_container = \''. $numcontainer_modify_ref .'\' WHERE cfe.rowid = '.$rowidcontainer;
                    
                        $containerupressql = $db->query($containerupsql);
                        dol_syslog("modification numéro container : " . $containerupsql, LOG_DEBUG);
                        $db->free($containerupressql);
                        
                    } else { // les extra-fields ne sont peut-être pas initialisés
                        // Commande fournisseur
                        $commfournisseursql = 'SELECT DISTINCT cf.rowid FROM '.MAIN_DB_PREFIX.'commande_fournisseur,'.MAIN_DB_PREFIX.'commande as c';
                        $commfournisseursql.= ' LEFT JOIN '.MAIN_DB_PREFIX.'element_element as ee ON ee.fk_source = c.rowid AND ee.sourcetype=\'commande\' AND ee.targettype=\'order_supplier\'';
                        $commfournisseursql.= ' LEFT JOIN '.MAIN_DB_PREFIX.'commande_fournisseur as cf ON ee.fk_target = cf.rowid AND ee.sourcetype=\'commande\' AND ee.targettype=\'order_supplier\'';
                        $commfournisseursql.= ' LEFT JOIN '.MAIN_DB_PREFIX.'commandedet as cd ON cd.fk_commande = c.rowid WHERE cd.rowid = '.$orderelementid;
                        dol_syslog("fournisseursql from list_commande_tri_regroupement numero : " . $commfournisseursql);
                        
                        $commfournisseurressql = $db->query($commfournisseursql);
                    
                        $objcount = $db->num_rows($commfournisseurressql);
                        dol_syslog("insertion numéro container objcount: " . $objcount, LOG_DEBUG);
                        
                        if ($objcount > 0) {
                            $commfournisseurobj = $db->fetch_object($commfournisseurressql);
                            $rowidcommfourn = $commfournisseurobj->rowid;
                            $commfourninsertsql = 'INSERT INTO '.MAIN_DB_PREFIX.'commande_fournisseur_extrafields (fk_id_container, fk_object) VALUES ('. $numcontainer_modify_ref . ',' . $rowidcommfourn . ')';

                            $commfourninsertressql = $db->query($commfourninsertsql);
                            dol_syslog("insertion numéro container dans extrafield: " . $commfourninsertsql, LOG_DEBUG);
                            $db->free(commfourninsertressql);
                        }
                    }
                    
                    $db->free($containerressql);    
                    
                }
                // Regeneration of full list
                $db->free($resql);
                $resql = $db->query($sql);
                //free selection
                //$arrayofselected = array();
            }
	}
        
        if ($massaction == 'modifycontainerdeparture' || $massaction == 'confirm_modifycontainerdeparture')
	{
            dol_syslog("modification date container departure massaction : " . $massaction);
            
            if ($massaction == 'modifycontainerdeparture') {
		print '<input type="hidden" name="massaction" value="confirm_modifycontainerdeparture">';

		print '<table class="noborder" width="100%" >';
		print '<tr>';
		print '<td class="titlefield">';
		print $langs->trans('DateDepartContainer');
		print '</td>';
		print '<td>';
                print '<script type=\'text/javascript\'>$(function(){ $(\'#departurecontainer_date_modify\').datepicker({
							dateFormat: \'dd/mm/yy\',
							autoclose: true,
							todayHighlight: true,
								showOn: \'button\',
								buttonImage: \'/theme/eldy/img/object_calendarday.png\',
								buttonImageOnly: true
							}) });</script><div class="nowrap inline-block"><input id="departurecontainer_date_modify" name="departurecontainer_date_modify" type="text" class="maxwidth75" maxlength="11" value="" onChange="dpChangeDay(\'departurecontainer_date_modify\',\'dd/MM/yyyy\'); "></div>';
		print '</td>';
		print '</tr>';
		print '</table>';

		print '<br>';
		print '<div class="center">';
		print '<input type="submit" class="button" id="modifycontainer" name="modifycontainer" value="'.$langs->trans('ModifyContainerDeparture').'">  ';
		print '<input type="submit" class="button" id="cancel" name="cancel" value="'.$langs->trans('Cancel').'">';
		print '</div>';
		print '<br>';
            } else {
                dol_syslog("modification date départ container count: " . count($arrayofselected), LOG_DEBUG);
                foreach($arrayofselected as $orderelementid) {
                    
                    // Container
                    $containersql = 'SELECT DISTINCT cfe.rowid FROM '.MAIN_DB_PREFIX.'commande_fournisseur_extrafields,'.MAIN_DB_PREFIX.'commande as c';
                    $containersql.= ' LEFT JOIN '.MAIN_DB_PREFIX.'element_element as ee ON ee.fk_source = c.rowid AND ee.sourcetype=\'commande\' AND ee.targettype=\'order_supplier\'';
                    $containersql.= ' LEFT JOIN '.MAIN_DB_PREFIX.'commande_fournisseur as cf ON ee.fk_target = cf.rowid AND ee.sourcetype=\'commande\' AND ee.targettype=\'order_supplier\'';
                    $containersql.= ' LEFT JOIN '.MAIN_DB_PREFIX.'commande_fournisseur_extrafields as cfe ON cf.rowid = cfe.fk_object';
                    $containersql.= ' LEFT JOIN '.MAIN_DB_PREFIX.'commandedet as cd ON cd.fk_commande = c.rowid WHERE cd.rowid = '.$orderelementid;
                    dol_syslog("containersql from list_commande_tri_regroupement date depart : " . $containersql);
                    
                    $containerressql = $db->query($containersql);
                    
                    $objcount = $db->num_rows($containerressql);
                    dol_syslog("modification date départ container objcount: " . $objcount, LOG_DEBUG);
                    if ($objcount > 0) {
                        $containerobj = $db->fetch_object($containerressql);
                        $rowidcontainer = $containerobj->rowid;
                        $containerupsql = 'UPDATE '.MAIN_DB_PREFIX.'commande_fournisseur_extrafields as cfe SET cfe.datedeparturecontainer = DATE(STR_TO_DATE(\''. $departurecontainer_date_modify .'\', \'%d/%m/%Y\')) WHERE cfe.rowid = '.$rowidcontainer;
                    } 
                    
                    $containerupressql = $db->query($containerupsql);
                    
                    $db->free($containerressql);
                    $db->free($containerupressql);
                    dol_syslog("modification date départ container : " . $containerupsql, LOG_DEBUG);
                    
                }
                // Regeneration of full list
                $db->free($resql);
                $resql = $db->query($sql);
                //free selection
                //$arrayofselected = array();
            }
	}

        if ($massaction == 'modifycontainerarrival' || $massaction == 'confirm_modifycontainerarrival')
	{
            dol_syslog("modification date container arrival massaction : " . $massaction);
            
            if ($massaction == 'modifycontainerarrival') {
		print '<input type="hidden" name="massaction" value="confirm_modifycontainerarrival">';

		print '<table class="noborder" width="100%" >';
		print '<tr>';
		print '<td class="titlefield">';
		print $langs->trans('DateArrivalContainer');
		print '</td>';
		print '<td>';
                print '<script type=\'text/javascript\'>$(function(){ $(\'#arrivalcontainer_date_modify\').datepicker({
							dateFormat: \'dd/mm/yy\',
							autoclose: true,
							todayHighlight: true,
								showOn: \'button\',
								buttonImage: \'/theme/eldy/img/object_calendarday.png\',
								buttonImageOnly: true
							}) });</script><div class="nowrap inline-block"><input id="arrivalcontainer_date_modify" name="arrivalcontainer_date_modify" type="text" class="maxwidth75" maxlength="11" value="" onChange="dpChangeDay(\'arrivalcontainer_date_modify\',\'dd/MM/yyyy\'); "></div>';
		print '</td>';
		print '</tr>';
		print '</table>';

		print '<br>';
		print '<div class="center">';
		print '<input type="submit" class="button" id="modifycontainer" name="modifycontainer" value="'.$langs->trans('ModifyContainerArrival').'">  ';
		print '<input type="submit" class="button" id="cancel" name="cancel" value="'.$langs->trans('Cancel').'">';
		print '</div>';
		print '<br>';
            } else {
                dol_syslog("modification date arrivée container count: " . count($arrayofselected), LOG_DEBUG);
                foreach($arrayofselected as $orderelementid) {
                    
                    // Container
                    $containersql = 'SELECT DISTINCT cfe.rowid FROM '.MAIN_DB_PREFIX.'commande_fournisseur_extrafields,'.MAIN_DB_PREFIX.'commande as c';
                    $containersql.= ' LEFT JOIN '.MAIN_DB_PREFIX.'element_element as ee ON ee.fk_source = c.rowid AND ee.sourcetype=\'commande\' AND ee.targettype=\'order_supplier\'';
                    $containersql.= ' LEFT JOIN '.MAIN_DB_PREFIX.'commande_fournisseur as cf ON ee.fk_target = cf.rowid AND ee.sourcetype=\'commande\' AND ee.targettype=\'order_supplier\'';
                    $containersql.= ' LEFT JOIN '.MAIN_DB_PREFIX.'commande_fournisseur_extrafields as cfe ON cf.rowid = cfe.fk_object';
                    $containersql.= ' LEFT JOIN '.MAIN_DB_PREFIX.'commandedet as cd ON cd.fk_commande = c.rowid WHERE cd.rowid = '.$orderelementid;
                    dol_syslog("containersql from list_commande_tri_regroupement date depart : " . $containersql);
                    
                    $containerressql = $db->query($containersql);
                    
                    $objcount = $db->num_rows($containerressql);
                    dol_syslog("modification date arrivée container objcount: " . $objcount, LOG_DEBUG);
                    if ($objcount > 0) {
                        $containerobj = $db->fetch_object($containerressql);
                        $rowidcontainer = $containerobj->rowid;
                        $containerupsql = 'UPDATE '.MAIN_DB_PREFIX.'commande_fournisseur_extrafields as cfe SET cfe.datearrivalcontainer = DATE(STR_TO_DATE(\''. $arrivalcontainer_date_modify .'\', \'%d/%m/%Y\')) WHERE cfe.rowid = '.$rowidcontainer;
                    } 
                    
                    $containerupressql = $db->query($containerupsql);
                    
                    $db->free($containerressql);
                    $db->free($containerupressql);
                    dol_syslog("modification date arrivée container : " . $containerupsql, LOG_DEBUG);
                    
                }
                // Regeneration of full list
                $db->free($resql);
                $resql = $db->query($sql);
                //free selection
                //$arrayofselected = array();
            }
	}

        
	if ($sall)
	{
		foreach($fieldstosearchall as $key => $val) $fieldstosearchall[$key]=$langs->trans($val);
		print '<div class="divsearchfieldfilter">'.$langs->trans("FilterOnInto", $sall) . join(', ',$fieldstosearchall).'</div>';
	}

	$moreforfilter='';

 	// If the user can view prospects other than his'
 	if ($user->rights->societe->client->voir || $socid)
 	{
 		$langs->load("commercial");
		$moreforfilter.='<div class="divsearchfield">';
 		$moreforfilter.=$langs->trans('ThirdPartiesOfSaleRepresentative'). ': ';
		$moreforfilter.=$formother->select_salesrepresentatives($search_sale, 'search_sale', $user, 0, 1, 'maxwidth200');
	 	$moreforfilter.='</div>';
 	}
	// If the user can view other users
	if ($user->rights->user->user->lire)
	{
		$moreforfilter.='<div class="divsearchfield">';
		$moreforfilter.=$langs->trans('LinkedToSpecificUsers'). ': ';
		$moreforfilter.=$form->select_dolusers($search_user, 'search_user', 1, '', 0, '', '', 0, 0, 0, '', 0, '', 'maxwidth200');
	 	$moreforfilter.='</div>';
	}
	// If the user can view prospects other than his'
	if ($conf->categorie->enabled && ($user->rights->produit->lire || $user->rights->service->lire))
	{
		include_once DOL_DOCUMENT_ROOT.'/categories/class/categorie.class.php';
		$moreforfilter.='<div class="divsearchfield">';
		$moreforfilter.=$langs->trans('IncludingProductWithTag'). ': ';
		$cate_arbo = $form->select_all_categories(Categorie::TYPE_PRODUCT, null, 'parent', null, null, 1);
		$moreforfilter.=$form->selectarray('search_product_category', $cate_arbo, $search_product_category, 1, 0, 0, '', 0, 0, 0, 0, 'maxwidth300', 1);
		$moreforfilter.='</div>';
	}
	if (! empty($conf->categorie->enabled))
	{
		require_once DOL_DOCUMENT_ROOT . '/categories/class/categorie.class.php';
		$moreforfilter.='<div class="divsearchfield">';
	 	$moreforfilter.=$langs->trans('CustomersProspectsCategoriesShort').': ';
		$moreforfilter.=$formother->select_categories('customer',$search_categ_cus,'search_categ_cus',1);
	 	$moreforfilter.='</div>';
	}
	$parameters=array();
	$reshook=$hookmanager->executeHooks('printFieldPreListTitle',$parameters);    // Note that $action and $object may have been modified by hook
	if (empty($reshook)) $moreforfilter .= $hookmanager->resPrint;
	else $moreforfilter = $hookmanager->resPrint;

	if (! empty($moreforfilter))
	{
		print '<div class="liste_titre liste_titre_bydiv centpercent">';
		print $moreforfilter;
		print '</div>';
	}

	$varpage=empty($contextpage)?$_SERVER["PHP_SELF"]:$contextpage;
	$selectedfields=$form->multiSelectArrayWithCheckbox('selectedfields', $arrayfields, $varpage);	// This also change content of $arrayfields
	$selectedfields.=$form->showCheckAddButtons('checkforselect', 1);

	print '<div class="div-table-responsive">';
	print '<table class="tagtable liste'.($moreforfilter?" listwithfilterbefore":"").'">'."\n";

	print '<tr class="liste_titre_filter">';
	// Ref
	if (! empty($arrayfields['c.ref']['checked']))
	{
		print '<td class="liste_titre">';
		print '<input class="flat" size="6" type="text" name="search_ref" value="'.$search_ref.'">';
		print '</td>';
	}
	// Ref customer
	if (! empty($arrayfields['c.ref_client']['checked']))
	{
		print '<td class="liste_titre" align="left">';
		print '<input class="flat" type="text" size="6" name="search_ref_customer" value="'.$search_ref_customer.'">';
		print '</td>';
	}
	// Project ref
	if (! empty($arrayfields['p.project_ref']['checked']))
	{
		print '<td class="liste_titre"><input type="text" class="flat" size="6" name="search_project_ref" value="'.$search_project_ref.'"></td>';
	}
	// Thirpdarty
	if (! empty($arrayfields['s.nom']['checked']))
	{
		print '<td class="liste_titre" align="left">';
		print '<input class="flat" type="text" name="search_company" value="'.$search_company.'">';
		print '</td>';
	}
	// Town
	if (! empty($arrayfields['s.town']['checked'])) print '<td class="liste_titre"><input class="flat" type="text" size="4" name="search_town" value="'.$search_town.'"></td>';
	// Zip
	if (! empty($arrayfields['s.zip']['checked'])) print '<td class="liste_titre"><input class="flat" type="text" size="4" name="search_zip" value="'.$search_zip.'"></td>';
	// State
	if (! empty($arrayfields['state.nom']['checked']))
	{
		print '<td class="liste_titre">';
		print '<input class="flat" size="4" type="text" name="search_state" value="'.dol_escape_htmltag($search_state).'">';
		print '</td>';
	}
	// Country
	if (! empty($arrayfields['country.code_iso']['checked']))
	{
		print '<td class="liste_titre" align="center">';
		print $form->select_country($search_country,'search_country','',0,'maxwidth100');
		print '</td>';
	}
	// Company type
	if (! empty($arrayfields['typent.code']['checked']))
	{
		print '<td class="liste_titre maxwidthonsmartphone" align="center">';
		print $form->selectarray("search_type_thirdparty", $formcompany->typent_array(0), $search_type_thirdparty, 0, 0, 0, '', 0, 0, 0, (empty($conf->global->SOCIETE_SORT_ON_TYPEENT)?'ASC':$conf->global->SOCIETE_SORT_ON_TYPEENT));
		print '</td>';
	}
	// Date order
	if (! empty($arrayfields['c.date_commande']['checked']))
	{
		print '<td class="liste_titre nowraponall" align="center">';
		if (! empty($conf->global->MAIN_LIST_FILTER_ON_DAY)) print '<input class="flat width25 valignmiddle" type="text" maxlength="2" name="search_orderday" value="'.$search_orderday.'">';
		print '<input class="flat width25 valignmiddle" type="text" maxlength="2" name="search_ordermonth" value="'.$search_ordermonth.'">';
		$formother->select_year($search_orderyear?$search_orderyear:-1,'search_orderyear',1, 20, 5);
		print '</td>';
	}
	if (! empty($arrayfields['c.date_delivery']['checked']))
	{
		print '<td class="liste_titre nowraponall" align="center">';
		if (! empty($conf->global->MAIN_LIST_FILTER_ON_DAY)) print '<input class="flat width25 valignmiddle" type="text" maxlength="2" name="search_deliveryday" value="'.$search_deliveryday.'">';
		print '<input class="flat width25 valignmiddle" type="text" maxlength="2" name="search_deliverymonth" value="'.$search_deliverymonth.'">';
		$formother->select_year($search_deliveryyear?$search_deliveryyear:-1,'search_deliveryyear',1, 20, 5);
		print '</td>';
	}
	if (! empty($arrayfields['c.total_ht']['checked']))
	{
		// Amount
		print '<td class="liste_titre" align="right">';
		print '<input class="flat" type="text" size="4" name="search_total_ht" value="'.$search_total_ht.'">';
		print '</td>';
	}
	if (! empty($arrayfields['c.total_vat']['checked']))
	{
		// Amount
		print '<td class="liste_titre" align="right">';
		print '<input class="flat" type="text" size="4" name="search_total_vat" value="'.$search_total_vat.'">';
		print '</td>';
	}
	if (! empty($arrayfields['c.total_ttc']['checked']))
	{
		// Amount
		print '<td class="liste_titre" align="right">';
		print '<input class="flat" type="text" size="5" name="search_total_ttc" value="'.$search_total_ttc.'">';
		print '</td>';
	}
        
        // Libre Expert 14/01/2019
        if (! empty($arrayfields['pde.numpalettecontainer']['checked']))
	{
		
		print '<td class="liste_titre" align="right">';
		print '<input class="flat" type="text" size="8" name="search_numpalette" value="'.$search_numpalette.'">';
		print '</td>';
	}
        if (! empty($arrayfields['pde.numcoliscontainer']['checked']))
	{
		
		print '<td class="liste_titre" align="right">';
		print '<input class="flat" type="text" size="8" name="search_numcolis" value="'.$search_numcolis.'">';
		print '</td>';
	}
        if (! empty($arrayfields['pdct.ref']['checked']))
	{
		
		print '<td class="liste_titre" align="right">';
		print '<input class="flat" type="text" size="8" name="search_product_ref" value="'.$search_product_ref.'">';
		print '</td>';
	}
        if (! empty($arrayfields['pfp.ref_fourn']['checked']))
	{
		
		print '<td class="liste_titre" align="right">';
		print '<input class="flat" type="text" size="8" name="search_product_fournisseur_ref" value="'.$search_product_fournisseur_ref.'">';
		print '</td>';
	}
        if (! empty($arrayfields['cf.ref']['checked']))
	{
		
		print '<td class="liste_titre" align="right">';
		print '<input class="flat" type="text" size="8" name="search_supplier_order" value="'.$search_supplier_order.'">';
		print '</td>';
	}        
        if (! empty($arrayfields['cont.ref']['checked']))
	{
		
		print '<td class="liste_titre" align="right">';
		print '<input class="flat" type="text" size="8" name="search_container_ref" value="'.$search_container_ref.'">';
		print '</td>';
	}
        if (! empty($arrayfields['cont.datedeparturecontainer']['checked']))
	{
		
		print '<td class="liste_titre" align="right">';
		print '<input class="flat" type="text" size="10" name="search_date_departure_container" value="'.$search_date_departure_container.'">';
		print '</td>';
	}
        if (! empty($arrayfields['cont.datearrivalcontainer']['checked']))
	{
		
		print '<td class="liste_titre" align="right">';
		print '<input class="flat" type="text" size="10" name="search_date_arrival_container" value="'.$search_date_arrival_container.'">';
		print '</td>';
	}
        //cfe.numcontainer, cfe.datedeparturecontainer, cfe.datearrivalcontainer
        //$search_container_ref='';
        //$search_date_arrival_container='';
        //$search_date_departure_container='';
        // End Libre Expert
        
	// Extra fields
	include DOL_DOCUMENT_ROOT.'/core/tpl/extrafields_list_search_input.tpl.php';
	// Fields from hook
	$parameters=array('arrayfields'=>$arrayfields);
	$reshook=$hookmanager->executeHooks('printFieldListOption',$parameters);    // Note that $action and $object may have been modified by hook
	print $hookmanager->resPrint;
	// Date creation
	if (! empty($arrayfields['c.datec']['checked']))
	{
		print '<td class="liste_titre">';
		print '</td>';
	}
	// Date modification
	if (! empty($arrayfields['c.tms']['checked']))
	{
		print '<td class="liste_titre">';
		print '</td>';
	}
	// Status
	if (! empty($arrayfields['c.fk_statut']['checked']))
	{
		print '<td class="liste_titre maxwidthonsmartphone" align="right">';
		$liststatus=array(
			Commande::STATUS_DRAFT=>$langs->trans("StatusOrderDraftShort"),
			Commande::STATUS_VALIDATED=>$langs->trans("StatusOrderValidated"),
			Commande::STATUS_SHIPMENTONPROCESS=>$langs->trans("StatusOrderSentShort"),
			Commande::STATUS_CLOSED=>$langs->trans("StatusOrderDelivered"),
			-3=>$langs->trans("StatusOrderValidatedShort").'+'.$langs->trans("StatusOrderSentShort").'+'.$langs->trans("StatusOrderDelivered"),
			Commande::STATUS_CANCELED=>$langs->trans("StatusOrderCanceledShort")
		);
		print $form->selectarray('viewstatut', $liststatus, $viewstatut, -4, 0, 0, '', 0, 0, 0, '', 'maxwidth100');
		print '</td>';
	}
	// Status billed
	if (! empty($arrayfields['c.facture']['checked']))
	{
		print '<td class="liste_titre maxwidthonsmartphone" align="center">';
		print $form->selectyesno('billed', $billed, 1, 0, 1);
		print '</td>';
	}
	// Action column
	print '<td class="liste_titre" align="middle">';
	$searchpicto=$form->showFilterButtons();
	print $searchpicto;
	print '</td>';

	print "</tr>\n";

	// Fields title
	print '<tr class="liste_titre">';
	if (! empty($arrayfields['c.ref']['checked']))            print_liste_field_titre($arrayfields['c.ref']['label'],$_SERVER["PHP_SELF"],'c.ref','',$param,'',$sortfield,$sortorder);
	if (! empty($arrayfields['c.ref_client']['checked']))     print_liste_field_titre($arrayfields['c.ref_client']['label'],$_SERVER["PHP_SELF"],'c.ref_client','',$param,'',$sortfield,$sortorder);
	if (! empty($arrayfields['p.project_ref']['checked'])) 	  print_liste_field_titre($arrayfields['p.project_ref']['label'],$_SERVER["PHP_SELF"],"p.ref","",$param,'',$sortfield,$sortorder);
	if (! empty($arrayfields['s.nom']['checked']))            print_liste_field_titre($arrayfields['s.nom']['label'],$_SERVER["PHP_SELF"],'s.nom','',$param,'',$sortfield,$sortorder);
	if (! empty($arrayfields['s.town']['checked']))           print_liste_field_titre($arrayfields['s.town']['label'],$_SERVER["PHP_SELF"],'s.town','',$param,'',$sortfield,$sortorder);
	if (! empty($arrayfields['s.zip']['checked']))            print_liste_field_titre($arrayfields['s.zip']['label'],$_SERVER["PHP_SELF"],'s.zip','',$param,'',$sortfield,$sortorder);
	if (! empty($arrayfields['state.nom']['checked']))        print_liste_field_titre($arrayfields['state.nom']['label'],$_SERVER["PHP_SELF"],"state.nom","",$param,'',$sortfield,$sortorder);
	if (! empty($arrayfields['country.code_iso']['checked'])) print_liste_field_titre($arrayfields['country.code_iso']['label'],$_SERVER["PHP_SELF"],"country.code_iso","",$param,'align="center"',$sortfield,$sortorder);
	if (! empty($arrayfields['typent.code']['checked']))      print_liste_field_titre($arrayfields['typent.code']['label'],$_SERVER["PHP_SELF"],"typent.code","",$param,'align="center"',$sortfield,$sortorder);
	if (! empty($arrayfields['c.date_commande']['checked']))  print_liste_field_titre($arrayfields['c.date_commande']['label'],$_SERVER["PHP_SELF"],'c.date_commande','',$param, 'align="center"',$sortfield,$sortorder);
	if (! empty($arrayfields['c.date_delivery']['checked']))  print_liste_field_titre($arrayfields['c.date_delivery']['label'],$_SERVER["PHP_SELF"],'c.date_livraison','',$param, 'align="center"',$sortfield,$sortorder);
	if (! empty($arrayfields['c.total_ht']['checked']))       print_liste_field_titre($arrayfields['c.total_ht']['label'],$_SERVER["PHP_SELF"],'c.total_ht','',$param, 'align="right"',$sortfield,$sortorder);
	if (! empty($arrayfields['c.total_vat']['checked']))      print_liste_field_titre($arrayfields['c.total_vat']['label'],$_SERVER["PHP_SELF"],'c.tva','',$param, 'align="right"',$sortfield,$sortorder);
	if (! empty($arrayfields['c.total_ttc']['checked']))      print_liste_field_titre($arrayfields['c.total_ttc']['label'],$_SERVER["PHP_SELF"],'c.total_ttc','',$param, 'align="right"',$sortfield,$sortorder);
	
        // Libre Expert 14/01/2019
        if (! empty($arrayfields['pde.numpalettecontainer']['checked']))      print_liste_field_titre($arrayfields['pde.numpalettecontainer']['label'],$_SERVER["PHP_SELF"],'pde.numpalettecontainer','',$param, 'align="right"',$sortfield,$sortorder);
	if (! empty($arrayfields['pde.numcoliscontainer']['checked']))      print_liste_field_titre($arrayfields['pde.numcoliscontainer']['label'],$_SERVER["PHP_SELF"],'pde.numcoliscontainer','',$param, 'align="right"',$sortfield,$sortorder);
	if (! empty($arrayfields['pdct.ref']['checked']))      print_liste_field_titre($arrayfields['pdct.ref']['label'],$_SERVER["PHP_SELF"],'pdct.ref','',$param, 'align="center"',$sortfield,$sortorder);
	if (! empty($arrayfields['pfp.ref_fourn']['checked']))      print_liste_field_titre($arrayfields['pfp.ref_fourn']['label'],$_SERVER["PHP_SELF"],'pfp.ref_fourn','',$param, 'align="center"',$sortfield,$sortorder);
        if (! empty($arrayfields['cf.ref']['checked']))      print_liste_field_titre($arrayfields['cf.ref']['label'],$_SERVER["PHP_SELF"],'cf.ref','',$param, 'align="center"',$sortfield,$sortorder);
        if (! empty($arrayfields['cont.ref']['checked']))      print_liste_field_titre($arrayfields['cont.ref']['label'],$_SERVER["PHP_SELF"],'cont.ref','',$param, 'align="right"',$sortfield,$sortorder);
	if (! empty($arrayfields['cont.datedeparturecontainer']['checked']))      print_liste_field_titre($arrayfields['cont.datedeparturecontainer']['label'],$_SERVER["PHP_SELF"],'cont.datedeparturecontainer','',$param, 'align="center"',$sortfield,$sortorder);
	if (! empty($arrayfields['cont.datearrivalcontainer']['checked']))      print_liste_field_titre($arrayfields['cont.datearrivalcontainer']['label'],$_SERVER["PHP_SELF"],'cont.datearrivalcontainer','',$param, 'align="center"',$sortfield,$sortorder);
         
        //cfe.numcontainer, cfe.datedeparturecontainer, cfe.datearrivalcontainer
        //$search_container_ref='';
        //$search_date_arrival_container='';
        //$search_date_departure_container='';
        // End Libre Expert
        
        // Extra fields
	include DOL_DOCUMENT_ROOT.'/core/tpl/extrafields_list_search_title.tpl.php';
	// Hook fields
	$parameters=array('arrayfields'=>$arrayfields,'param'=>$param,'sortfield'=>$sortfield,'sortorder'=>$sortorder);
	$reshook=$hookmanager->executeHooks('printFieldListTitle',$parameters);    // Note that $action and $object may have been modified by hook
	print $hookmanager->resPrint;
	if (! empty($arrayfields['c.datec']['checked']))     print_liste_field_titre($arrayfields['c.datec']['label'],$_SERVER["PHP_SELF"],"c.date_creation","",$param,'align="center" class="nowrap"',$sortfield,$sortorder);
	if (! empty($arrayfields['c.tms']['checked']))       print_liste_field_titre($arrayfields['c.tms']['label'],$_SERVER["PHP_SELF"],"c.tms","",$param,'align="center" class="nowrap"',$sortfield,$sortorder);
	if (! empty($arrayfields['c.fk_statut']['checked'])) print_liste_field_titre($arrayfields['c.fk_statut']['label'],$_SERVER["PHP_SELF"],"c.fk_statut","",$param,'align="right"',$sortfield,$sortorder);
	if (! empty($arrayfields['c.facture']['checked']))   print_liste_field_titre($arrayfields['c.facture']['label'],$_SERVER["PHP_SELF"],'c.facture','',$param,'align="center"',$sortfield,$sortorder,'');
	print_liste_field_titre($selectedfields, $_SERVER["PHP_SELF"],"",'',$param,'align="center"',$sortfield,$sortorder,'maxwidthsearch ');
	print '</tr>'."\n";

	$total=0;
	$subtotal=0;
	$productstat_cache=array();

	$generic_commande = new Commande($db);
	$generic_product = new Product($db);

	$i=0;
	$totalarray=array();
	while ($i < min($num,$limit))
	{
		$obj = $db->fetch_object($resql);

		$notshippable=0;
		$warning = 0;
		$text_info='';
		$text_warning='';
		$nbprod=0;

		$companystatic->id=$obj->socid;
		$companystatic->code_client = $obj->code_client;
		$companystatic->name=$obj->name;
		$companystatic->client=$obj->client;
		$companystatic->email=$obj->email;

		$generic_commande->id=$obj->rowid;
		$generic_commande->ref=$obj->ref;
		$generic_commande->statut = $obj->fk_statut;
		$generic_commande->date_commande = $db->jdate($obj->date_commande);
		$generic_commande->date_livraison = $db->jdate($obj->date_delivery);
		$generic_commande->ref_client = $obj->ref_client;
		$generic_commande->total_ht = $obj->total_ht;
		$generic_commande->total_tva = $obj->total_tva;
		$generic_commande->total_ttc = $obj->total_ttc;

		print '<tr class="oddeven">';

		// Ref
		if (! empty($arrayfields['c.ref']['checked']))
		{
			print '<td class="nowrap">';

			$generic_commande->lines=array();
			$generic_commande->getLinesArray();

			print '<table class="nobordernopadding"><tr class="nocellnopadd">';
			print '<td class="nobordernopadding nowrap">';
			print $generic_commande->getNomUrl(1, ($viewstatut != 2?0:$obj->fk_statut), 0, 0, 0, 1);
			print '</td>';

			// Show shippable Icon (create subloop, so may be slow)
			if ($conf->stock->enabled)
			{
				$langs->load("stocks");
				if (($obj->fk_statut > 0) && ($obj->fk_statut < 3))
				{
					$numlines = count($generic_commande->lines); // Loop on each line of order
					for ($lig=0; $lig < $numlines; $lig++)
					{
						if ($generic_commande->lines[$lig]->product_type == 0 && $generic_commande->lines[$lig]->fk_product > 0)  // If line is a product and not a service
						{
							$nbprod++; // order contains real products
							$generic_product->id = $generic_commande->lines[$lig]->fk_product;

							// Get local and virtual stock and store it into cache
							if (empty($productstat_cache[$generic_commande->lines[$lig]->fk_product])) {
								$generic_product->load_stock('nobatch');
								//$generic_product->load_virtual_stock();   Already included into load_stock
								$productstat_cache[$generic_commande->lines[$lig]->fk_product]['stock_reel'] = $generic_product->stock_reel;
								$productstat_cachevirtual[$generic_commande->lines[$lig]->fk_product]['stock_reel'] = $generic_product->stock_theorique;
							} else {
								$generic_product->stock_reel = $productstat_cache[$generic_commande->lines[$lig]->fk_product]['stock_reel'];
								$generic_product->stock_theorique = $productstat_cachevirtual[$generic_commande->lines[$lig]->fk_product]['stock_reel'] = $generic_product->stock_theorique;
							}

							if (empty($conf->global->SHIPPABLE_ORDER_ICON_IN_LIST))  // Default code. Default is when this option is not set, setting it create strange result
							{
								$text_info .= $generic_commande->lines[$lig]->qty.' X '.$generic_commande->lines[$lig]->ref.'&nbsp;'.dol_trunc($generic_commande->lines[$lig]->product_label, 25);
								$text_info .= ' - '.$langs->trans("Stock").': '.$generic_product->stock_reel;
								$text_info .= ' - '.$langs->trans("VirtualStock").': '.$generic_product->stock_theorique;
								$text_info .= '<br>';

								if ($generic_commande->lines[$lig]->qty > $generic_product->stock_reel)
								{
									$notshippable++;
								}
							}
							else {  // Detailed code, looks bugged
								// stock order and stock order_supplier
								$stock_order=0;
								$stock_order_supplier=0;
								if (! empty($conf->global->STOCK_CALCULATE_ON_SHIPMENT) || ! empty($conf->global->STOCK_CALCULATE_ON_SHIPMENT_CLOSE))    // What about other options ?
								{
									if (! empty($conf->commande->enabled))
									{
										if (empty($productstat_cache[$generic_commande->lines[$lig]->fk_product]['stats_order_customer'])) {
											$generic_product->load_stats_commande(0,'1,2');
											$productstat_cache[$generic_commande->lines[$lig]->fk_product]['stats_order_customer'] = $generic_product->stats_commande['qty'];
										} else {
											$generic_product->stats_commande['qty'] = $productstat_cache[$generic_commande->lines[$lig]->fk_product]['stats_order_customer'];
										}
										$stock_order=$generic_product->stats_commande['qty'];
									}
									if (! empty($conf->fournisseur->enabled))
									{
										if (empty($productstat_cache[$generic_commande->lines[$lig]->fk_product]['stats_order_supplier'])) {
											$generic_product->load_stats_commande_fournisseur(0,'3');
											$productstat_cache[$generic_commande->lines[$lig]->fk_product]['stats_order_supplier'] = $generic_product->stats_commande_fournisseur['qty'];
										} else {
											$generic_product->stats_commande_fournisseur['qty'] = $productstat_cache[$generic_commande->lines[$lig]->fk_product]['stats_order_supplier'];
										}
										$stock_order_supplier=$generic_product->stats_commande_fournisseur['qty'];
									}
								}
								$text_info .= $generic_commande->lines[$lig]->qty.' X '.$generic_commande->lines[$lig]->ref.'&nbsp;'.dol_trunc($generic_commande->lines[$lig]->product_label, 25);
								$text_stock_reel = $generic_product->stock_reel.'/'.$stock_order;
								if ($stock_order > $generic_product->stock_reel && ! ($generic_product->stock_reel < $generic_commande->lines[$lig]->qty)) {
									$warning++;
									$text_warning.='<span class="warning">'.$langs->trans('Available').'&nbsp;:&nbsp;'.$text_stock_reel.'</span>';
								}
								if ($generic_product->stock_reel < $generic_commande->lines[$lig]->qty) {
									$notshippable++;
									$text_info.='<span class="warning">'.$langs->trans('Available').'&nbsp;:&nbsp;'.$text_stock_reel.'</span>';
								} else {
									$text_info.='<span class="ok">'.$langs->trans('Available').'&nbsp;:&nbsp;'.$text_stock_reel.'</span>';
								}
								if (! empty($conf->fournisseur->enabled)) {
									$text_info.= '&nbsp;'.$langs->trans('SupplierOrder').'&nbsp;:&nbsp;'.$stock_order_supplier.'<br>';
								} else {
									$text_info.= '<br>';
								}
							}
						}
					}
					if ($notshippable==0) {
						$text_icon = img_picto('', 'object_sending');
						$text_info = $langs->trans('Shippable').'<br>'.$text_info;
					} else {
						$text_icon = img_picto('', 'error');
						$text_info = $langs->trans('NonShippable').'<br>'.$text_info;
					}
				}

				print '<td>';
				if ($nbprod)
				{
					print $form->textwithtooltip('',$text_info,2,1,$text_icon,'',2);
				}
				if ($warning) {     // Always false in default mode
					print $form->textwithtooltip('', $langs->trans('NotEnoughForAllOrders').'<br>'.$text_warning, 2, 1, img_picto('', 'error'),'',2);
				}
				print '</td>';
			}

			// Warning late icon and note
			print '<td class="nobordernopadding nowrap">';
			if ($generic_commande->hasDelay()) {
				print img_picto($langs->trans("Late").' : '.$generic_commande->showDelay(), "warning");
			}
			if (!empty($obj->note_private) || !empty($obj->note_public))
			{
				print ' <span class="note">';
				print '<a href="'.DOL_URL_ROOT.'/commande/note.php?id='.$obj->rowid.'">'.img_picto($langs->trans("ViewPrivateNote"),'object_generic').'</a>';
				print '</span>';
			}
			print '</td>';

			print '<td width="16" align="right" class="nobordernopadding hideonsmartphone">';
			$filename=dol_sanitizeFileName($obj->ref);
			$filedir=$conf->commande->dir_output . '/' . dol_sanitizeFileName($obj->ref);
			$urlsource=$_SERVER['PHP_SELF'].'?id='.$obj->rowid;
			print $formfile->getDocumentsLink($generic_commande->element, $filename, $filedir);
			print '</td>';
			print '</tr></table>';

			print '</td>';
			if (! $i) $totalarray['nbfield']++;
		}

		// Ref customer
		if (! empty($arrayfields['c.ref_client']['checked']))
		{
			print '<td>'.$obj->ref_client.'</td>';
			if (! $i) $totalarray['nbfield']++;
		}

		// Project
		if (! empty($arrayfields['p.project_ref']['checked']))
		{
			$projectstatic->id=$obj->project_id;
			$projectstatic->ref=$obj->project_ref;
			print '<td>';
			if ($obj->project_id > 0) print $projectstatic->getNomUrl(1);
			print '</td>';
			if (! $i) $totalarray['nbfield']++;
		}

		// Third party
		if (! empty($arrayfields['s.nom']['checked']))
		{
			print '<td class="tdoverflowmax200">';
			print $companystatic->getNomUrl(1,'customer');

			// If module invoices enabled and user with invoice creation permissions
			if (! empty($conf->facture->enabled) && ! empty($conf->global->ORDER_BILLING_ALL_CUSTOMER))
			{
				if ($user->rights->facture->creer)
				{
					if (($obj->fk_statut > 0 && $obj->fk_statut < 3) || ($obj->fk_statut == 3 && $obj->billed == 0))
					{
						print '&nbsp;<a href="'.DOL_URL_ROOT.'/commande/orderstoinvoice.php?socid='.$companystatic->id.'">';
						print img_picto($langs->trans("CreateInvoiceForThisCustomer").' : '.$companystatic->name, 'object_bill', 'hideonsmartphone').'</a>';
					}
				}
			}
			print '</td>';
			if (! $i) $totalarray['nbfield']++;
		}
		// Town
		if (! empty($arrayfields['s.town']['checked']))
		{
			print '<td class="nocellnopadd">';
			print $obj->town;
			print '</td>';
			if (! $i) $totalarray['nbfield']++;
		}
		// Zip
		if (! empty($arrayfields['s.zip']['checked']))
		{
			print '<td class="nocellnopadd">';
			print $obj->zip;
			print '</td>';
			if (! $i) $totalarray['nbfield']++;
		}
		// State
		if (! empty($arrayfields['state.nom']['checked']))
		{
			print "<td>".$obj->state_name."</td>\n";
			if (! $i) $totalarray['nbfield']++;
		}
		// Country
		if (! empty($arrayfields['country.code_iso']['checked']))
		{
			print '<td align="center">';
			$tmparray=getCountry($obj->fk_pays,'all');
			print $tmparray['label'];
			print '</td>';
			if (! $i) $totalarray['nbfield']++;
		}
		// Type ent
		if (! empty($arrayfields['typent.code']['checked']))
		{
			print '<td align="center">';
			if (count($typenArray)==0) $typenArray = $formcompany->typent_array(1);
			print $typenArray[$obj->typent_code];
			print '</td>';
			if (! $i) $totalarray['nbfield']++;
		}

		// Order date
		if (! empty($arrayfields['c.date_commande']['checked']))
		{
			print '<td align="center">';
			print dol_print_date($db->jdate($obj->date_commande), 'day');
			print '</td>';
			if (! $i) $totalarray['nbfield']++;
		}
		// Plannned date of delivery
		if (! empty($arrayfields['c.date_delivery']['checked']))
		{
			print '<td align="center">';
			print dol_print_date($db->jdate($obj->date_delivery), 'day');
			print '</td>';
			if (! $i) $totalarray['nbfield']++;
		}
		// Amount HT
		if (! empty($arrayfields['c.total_ht']['checked']))
		{
			  print '<td align="right">'.price($obj->total_ht)."</td>\n";
			  if (! $i) $totalarray['nbfield']++;
			  if (! $i) $totalarray['totalhtfield']=$totalarray['nbfield'];
			  $totalarray['totalht'] += $obj->total_ht;
		}
		// Amount VAT
		if (! empty($arrayfields['c.total_vat']['checked']))
		{
			print '<td align="right">'.price($obj->total_tva)."</td>\n";
			if (! $i) $totalarray['nbfield']++;
			if (! $i) $totalarray['totalvatfield']=$totalarray['nbfield'];
			$totalarray['totalvat'] += $obj->total_tva;
		}
		// Amount TTC
		if (! empty($arrayfields['c.total_ttc']['checked']))
		{
			print '<td align="right">'.price($obj->total_ttc)."</td>\n";
			if (! $i) $totalarray['nbfield']++;
			if (! $i) $totalarray['totalttcfield']=$totalarray['nbfield'];
			$totalarray['totalttc'] += $obj->total_ttc;
		}
                
                // Libre Expert 14/01/2019
		if (! empty($arrayfields['pde.numpalettecontainer']['checked']))
		{
			print '<td align="right">'.$obj->numpalettecontainer.'</td>';
			if (! $i) $totalarray['nbfield']++;	
		}
                if (! empty($arrayfields['pde.numcoliscontainer']['checked']))
		{
			print '<td align="right">'.$obj->numcoliscontainer.'</td>';
			if (! $i) $totalarray['nbfield']++;	
		}
                if (! empty($arrayfields['pdct.ref']['checked']))
		{
                        $product_static=new Product($db);
                        $product_static->id = $obj->product_rowid;
			$product_static->ref = $obj->product_ref;
			$product_static->label = $obj->product_label;
			//print '<td align="right">'.$obj->product_ref.'</td>';
                        print '<td class="tdoverflowmax200">';
			print $product_static->getNomUrl(1);
			print "</td>\n";
			if (! $i) $totalarray['nbfield']++;	
		}
                if (! empty($arrayfields['pfp.ref_fourn']['checked']))
		{
			print '<td align="right">'.$obj->ref_fourn.'</td>';
			if (! $i) $totalarray['nbfield']++;	
		}
                if (! empty($arrayfields['cf.ref']['checked']))
		{
			//print '<td class="nowrap">';

			//print '<table class="nobordernopadding"><tr class="nocellnopadd">';
			// Picto + Ref
			print '<td class="nobordernopadding nowrap">';
                        $objectstatic=new CommandeFournisseur($db);
                        $objectstatic->id=$obj->commande_fournisseur_rowid;
                        $objectstatic->ref=$obj->commande_fournisseur_ref;
			print $objectstatic->getNomUrl(1);


			print '</td>'."\n";
			if (! $i) $totalarray['nbfield']++;
		}

                if (! empty($arrayfields['cont.ref']['checked']))
		{
			//print '<td align="right">'.$obj->numcontainer.'</td>';
                    	print '<td class="nobordernopadding nowrap">';
                        $containerstatic=new Container($db);
                        $containerstatic->id=$obj->container_rowid;
                        $containerstatic->ref=$obj->numcontainer;
			print $containerstatic->getNomUrl(1);
			print '</td>'."\n";
			if (! $i) $totalarray['nbfield']++;	
		}
                if (! empty($arrayfields['cont.datedeparturecontainer']['checked']))
		{
			print '<td align="center">'.dol_print_date($db->jdate($obj->datedeparturecontainer), 'day').'</td>';
			if (! $i) $totalarray['nbfield']++;	
		}
                if (! empty($arrayfields['cont.datearrivalcontainer']['checked']))
		{
			print '<td align="center">'.dol_print_date($db->jdate($obj->datearrivalcontainer), 'day').'</td>';
			if (! $i) $totalarray['nbfield']++;	
		}
                //cfe.numcontainer, cfe.datedeparturecontainer, cfe.datearrivalcontainer
                //$search_container_ref='';
                //$search_date_arrival_container='';
                //$search_date_departure_container='';
                // End Libre Expert

		// Extra fields
		include DOL_DOCUMENT_ROOT.'/core/tpl/extrafields_list_print_fields.tpl.php';
		// Fields from hook
		$parameters=array('arrayfields'=>$arrayfields, 'obj'=>$obj);
		$reshook=$hookmanager->executeHooks('printFieldListValue',$parameters);    // Note that $action and $object may have been modified by hook
		print $hookmanager->resPrint;
		// Date creation
		if (! empty($arrayfields['c.datec']['checked']))
		{
			print '<td align="center" class="nowrap">';
			print dol_print_date($db->jdate($obj->date_creation), 'dayhour', 'tzuser');
			print '</td>';
			if (! $i) $totalarray['nbfield']++;
		}
		// Date modification
		if (! empty($arrayfields['c.tms']['checked']))
		{
			print '<td align="center" class="nowrap">';
			print dol_print_date($db->jdate($obj->date_update), 'dayhour', 'tzuser');
			print '</td>';
			if (! $i) $totalarray['nbfield']++;
		}
		// Status
		if (! empty($arrayfields['c.fk_statut']['checked']))
		{
			print '<td align="right" class="nowrap">'.$generic_commande->LibStatut($obj->fk_statut, $obj->billed, 5, 1).'</td>';
			if (! $i) $totalarray['nbfield']++;
		}
		// Billed
		if (! empty($arrayfields['c.facture']['checked']))
		{
			print '<td align="center">'.yn($obj->billed).'</td>';
			if (! $i) $totalarray['nbfield']++;
		}

		// Action column
		print '<td class="nowrap" align="center">';
		if ($massactionbutton || $massaction)   // If we are in select mode (massactionbutton defined) or if we have already selected and sent an action ($massaction) defined
		{
			$selected=0;
//			if (in_array($obj->rowid, $arrayofselected)) $selected=1;
//			print '<input id="cb'.$obj->rowid.'" class="flat checkforselect" type="checkbox" name="toselect[]" value="'.$obj->rowid.'"'.($selected?' checked="checked"':'').'>';
                        if (in_array($obj->order_element_rowid, $arrayofselected)) $selected=1;
			print '<input id="cb'.$obj->order_element_rowid.'" class="flat checkforselect" type="checkbox" name="toselect[]" value="'.$obj->order_element_rowid.'"'.($selected?' checked="checked"':'').'>';

                }
		print '</td>';
		if (! $i) $totalarray['nbfield']++;

		print "</tr>\n";

		$total+=$obj->total_ht;
		$subtotal+=$obj->total_ht;
		$i++;
	}

	// Show total line
	if (isset($totalarray['totalhtfield'])
 	   || isset($totalarray['totalvatfield'])
 	   || isset($totalarray['totalttcfield'])
 	   || isset($totalarray['totalamfield'])
 	   || isset($totalarray['totalrtpfield'])
 	   )
	{
		print '<tr class="liste_total">';
		$i=0;
		while ($i < $totalarray['nbfield'])
		{
			$i++;
			if ($i == 1)
			{
				if ($num < $limit && empty($offset)) print '<td align="left">'.$langs->trans("Total").'</td>';
				else print '<td align="left">'.$langs->trans("Totalforthispage").'</td>';
			}
			elseif ($totalarray['totalhtfield'] == $i) print '<td align="right">'.price($totalarray['totalht']).'</td>';
			elseif ($totalarray['totalvatfield'] == $i) print '<td align="right">'.price($totalarray['totalvat']).'</td>';
			elseif ($totalarray['totalttcfield'] == $i) print '<td align="right">'.price($totalarray['totalttc']).'</td>';
			else print '<td></td>';
		}
		print '</tr>';
	}

	$db->free($resql);

	$parameters=array('arrayfields'=>$arrayfields, 'sql'=>$sql);
	$reshook=$hookmanager->executeHooks('printFieldListFooter',$parameters);    // Note that $action and $object may have been modified by hook
	print $hookmanager->resPrint;

	print '</table>'."\n";
	print '</div>';

	print '</form>'."\n";

	$hidegeneratedfilelistifempty=1;
	if ($massaction == 'builddoc' || $action == 'remove_file' || $show_files) $hidegeneratedfilelistifempty=0;

	// Show list of available documents
	$urlsource=$_SERVER['PHP_SELF'].'?sortfield='.$sortfield.'&sortorder='.$sortorder;
	$urlsource.=str_replace('&amp;','&',$param);

	$filedir=$diroutputmassaction;
	$genallowed=$user->rights->commande->lire;
	$delallowed=$user->rights->commande->creer;

      	print $formfile->showdocuments('massfilesarea_orders','',$filedir,$urlsource,0,$delallowed,'',1,1,0,48,1,$param,$langs->trans('PDFEinsteinPicklistDescription'),'','','',null,$hidegeneratedfilelistifempty);
	//print $formfile->showdocuments('commande','',$filedir,$urlsource,1,$delallowed,'einsteinpicklist',1,1,0,48,1,$param,$langs->trans('PDFEinsteinPicklistDescription'),'','','',null,$hidegeneratedfilelistifempty);
}
else
{
	dol_print_error($db);
}

llxFooter();
$db->close();
